clear
set more off
set mem 500m

*Generating 02_ETH_EXPALCH.dta*

cd "C:\AFRCE\Ethiopia 2004"
use "02_CLEANDATA\HICES\cons2004_ict.dta", clear

des  /*initial number of observations is 1,813,186*/

sort HID

codebook HID  /*21,595 households*/

/*NOTE: First thing to do in this dataset is to recode the UR variable to match
the code of the same variable in the demographic_con2004 dataset. This allows for a 
successful merging of the datasets*/

recode UR 1=2 2=1
lab def UR 1"rural" 2 "urban", replace
lab val UR UR

tab UR
tab UR,nol

*Generating FDALC_B variable*
*-------------------------------
gen FDALC_B=EXPEN if CQ16==1 & [[CQ17>=2 & CQ17<=6] | [CQ17>=8 & CQ17<=16]] & [CQ15>=11001 & CQ15<=11015] | [CQ15==11098]
replace FDALC_B=EXPEN if CQ16==1 & [[CQ17>=2 & CQ17<=6] | [CQ17>=8 & CQ17<=16]] & [CQ15>=11101 & CQ15<=11108]

*Generating FDALC_P variable*
*------------------------------
gen FDALC_P=EXPEN if CQ16==2 & [CQ17==1|CQ17==7] & [CQ15>=11001 & CQ15<=11015] | [CQ15==11098]
replace FDALC_P=EXPEN if CQ16==2 & [CQ17==1|CQ17==7] & [CQ15>=11101 & CQ15<=11108]

*Generating TOBACCO variable*
*------------------------------
gen TOBACCO=EXPEN if [CQ16==1|CQ16==2] & [CQ17>=1 & CQ17<=16] & [CQ15>=11201 & CQ15<=11230] | [CQ15==11298]
replace TOBACCO=EXPEN if [CQ16==1|CQ16==2] & [CQ17>=1 & CQ17<=16] & [CQ15>=11301 & CQ15<=11306] | [CQ15==11398]

*Generating NARCOTICS variable*
*--------------------------------
gen NARCOTICS=EXPEN if [CQ16==1|CQ16==2] & [CQ17>=1 & CQ17<=16] & [CQ15==1608]

collapse (sum)FDALC_B FDALC_P TOBACCO NARCOTICS, by (HID)

des /*21,595 observations*/
*-----------------------------------------------------------------------------------------------------

*Merging variable from file 00_ETH_BASICINFO*
*-----------------------------------------------
sort HID
merge HID using 04_AGGDATA\00_ETH_BASICINFO, keep (RURURB)
tab _merge  /*21,595 observations*/
drop _merge

des /*21,595 households*/

*Annualizing the variables*
*---------------------------
*expenditure values are already annualized in the dataset*

*Generating TOTALCH variable*
*-----------------------------
egen TOTALCH =rowtotal(FDALC_B FDALC_P TOBACCO NARCOTICS)

*Labeling the variables*
*-------------------------
lab val FDALC_B FDALC_B
label var FDALC_B "Total expenditure on purchased alcoholic beverages"

lab val FDALC_P FDALC_P
label var FDALC_P "Total value of alcoholic beverages other than purchased"

lab val TOBACCO TOBACCO 
label var TOBACCO "Total (expenditure on/value of)(tobacco/tobacco products)(purchased/received/produced)"

lab val NARCOTICS NARCOTICS
label var NARCOTICS "Total (expenditure on/value of)(narcotics/narcotics products)(purchased/received/produced)"

lab val TOTALCH TOTALCH
label var TOTALCH "Total expenditure on alcoholic beverages, tobacco, and narcotics)"

order HID RURURB FDALC_B FDALC_P TOBACCO NARCOTICS TOTALCH 

des /*number of observations is 21,595*/

sort HID

save "04_AGGDATA\02_ETH_EXPALCH", replace






