clear
set more off
set mem 500m

*Generating 03_ETH_EXPCLTH.dta*

cd "C:\AFRCE\Ethiopia 2004"
use "02_CLEANDATA\HICES\cons2004_ict.dta", clear

des  /*initial number of observations is 1,813,186*/

sort HID

codebook HID  /*21,595 households*/

/*NOTE: First thing to do in this dataset is to recode the UR variable
to match the code of the same variable in the demographic_con2004 dataset. This allows 
for a successful merging of the datasets*/

recode UR 1=2 2=1
lab def UR 1"rural" 2 "urban", replace
lab val UR UR

tab UR
tab UR,nol

*Generating HSCLOTH variable*
*------------------------------
gen HSCLOTH=EXPEN if [CQ15>=20101 & CQ15<=20119] | [CQ15==20128|CQ15==20131|CQ15==20198]
replace HSCLOTH=EXPEN if [CQ15>=20201 & CQ15<=20207] | [CQ15==20211|CQ15==20217|CQ15==20298]
replace HSCLOTH=EXPEN if [CQ15>=20301 & CQ15<=20370] | [CQ15==20372|CQ15==20374|CQ15==20375|CQ15==20377|CQ15==20378]
replace HSCLOTH=EXPEN if [CQ15>=20380 & CQ15<=20385] | [CQ15==20389]
replace HSCLOTH=EXPEN if [CQ15>=20390 & CQ15<=20394] | [CQ15==20398]
replace HSCLOTH=EXPEN if [CQ15>=20401 & CQ15<=20407]
replace HSCLOTH=EXPEN if [CQ15>=20409 & CQ15<=20418]
replace HSCLOTH=EXPEN if [CQ15>=20420 & CQ15<=20439]
replace HSCLOTH=EXPEN if [CQ15>=20444 & CQ15<=20798]
replace HSCLOTH=EXPEN if [CQ15==21101|CQ15==21102|CQ15==21103]

*Generating HSFOOTW variable*
*------------------------------
gen HSFOOTW=EXPEN if [CQ15>=20801 & CQ15<=20832] | [CQ15==20898]
replace HSFOOTW=EXPEN if [CQ15>=20901 & CQ15<=20926] | [CQ15==20998]
replace HSFOOTW=EXPEN if [CQ15>=21001 & CQ15<=21020] | [CQ15==21098|CQ15==21104]

collapse (sum)HSCLOTH HSFOOTW, by (HID)

des /*Total # of observations is 21,595 (households)*/
*---------------------------------------------------------------------------------------

*Merging variables from file 00_ETH_BASICINFO*
*-----------------------------------------------

sort HID
merge HID using "04_AGGDATA\00_ETH_BASICINFO.dta", keep (RURURB)
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge

des /*21,595 observations (households)*/

*Annualizing the variables*
*-----------------------------
*expenditure values are already annualized in the dataset*

*Generating TOTCLTH variable*
*-------------------------------
egen TOTCLTH =rowtotal(HSCLOTH HSFOOTW)

*Labeling the variables*
*-------------------------
lab val HSCLOTH HSCLOTH
label var HSCLOTH "Total expenditure on clothing and its repair including gifted/self-produced"

lab val HSFOOTW HSFOOTW
label var HSFOOTW "Total expenditure on footware and its repair including gifted/self-produced"

lab val TOTCLTH TOTCLTH
label var TOTCLTH "Total expenditure on clothing and footware"

order HID RURURB HSCLOTH HSFOOTW TOTCLTH 

des /*number of observations is 21,595*/

sort HID

save "04_AGGDATA\03_ETH_EXPCLTH", replace
