clear
set more off
set mem 500m

*Generating 04_ETH_EXPHOUS.dta*

cd "C:\AFRCE\Ethiopia 2004"
use "02_CLEANDATA\HICES\cons2004_ict.dta", clear

des  /*initial number of observations is 1,813,186*/

sort HID

codebook HID  /*21,595 households*/

/*NOTE: First thing to do in this dataset is to recode the UR variable to 
match the code of the same variable in the demographic_con2004 dataset. This allows
for a successful merging of the datasets*/

recode UR 1=2 2=1
lab def UR 1"rural" 2 "urban", replace
lab val UR UR

tab UR
tab UR,nol

*Generating RENT_ACT variable*
*--------------------------------
gen RENT_ACT=EXPEN if [CQ15>=30101 & CQ15<=30103] | [CQ15==30105|CQ15==30198]

*Generating RENT_IMP variable*
*--------------------------------
gen RENT_IMP=EXPEN if [CQ15==30104|CQ15==30106]

*Generating HSREPAIR variable*
*--------------------------------
gen HSREPAIR=EXPEN if [CQ15>=30201 & CQ15<=30298]

*Generating HSWATER variable*
*-----------------------------
gen HSWATER=EXPEN if [CQ15>=30301 & CQ15<=30303] |[CQ15==30305|CQ15==30307|CQ15==30398]

*Generating HSFULEL*
*----------------------
gen HSFUEL=EXPEN if [CQ15>=30401 & CQ15<=30405] | [CQ15==30412|CQ15==30498]

*Generating GAS variable*
*-------------------------
gen GAS=EXPEN if CQ15==30410

*Generating ELEC variable*
*-----------------------------
gen ELEC=EXPEN if CQ15==30407

*Generating HSKEROSENE variable*
*-----------------------------------
gen HSKEROSENE=EXPEN if CQ15==30406

*Generating HSDIESEL variable*
*---------------------------------
gen HSDIESEL=.

*Generating HSUTILITY variable*
*---------------------------------
egen HSUTILITY=rowtotal (GAS ELEC)

collapse (sum) RENT_ACT RENT_IMP HSREPAIR HSWATER HSFUEL GAS ELEC HSKEROSENE HSDIESEL HSUTILITY, by (HID)

des /*Total # of observations is 21,595 (households)*/
*-----------------------------------------------------------------------------------------------------

*Merging variables from file 00_ETH_BASICINFO*
*----------------------------------------------
sort HID
merge HID using "04_AGGDATA\00_ETH_BASICINFO.dta", keep (RURURB)
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge

des /*21,595 observations (households)*/

*Annualizing the variables*
*-----------------------------
*expenditure values are already annualized in the dataset*

*Generating TOTHOUS variable*
*-------------------------------
egen TOTHOUS =rowtotal(HSREPAIR HSWATER HSFUEL HSKEROSENE HSDIESEL HSUTILITY)

*Labeling the variables*
*---------------------------
lab val RENT_ACT RENT_ACT
label var RENT_ACT "Actual rentals for housing"

lab val RENT_IMP RENT_IMP
label var RENT_IMP "Imputed rentals for housing - SAME AS OWNER OCCUPIED HOUSING RENT"

lab val HSREPAIR HSREPAIR
label var HSREPAIR "Expenditure on maintenance and repair of dwelling"

lab val HSWATER HSWATER
label var HSWATER "Expenditure on water supply and miscellaneous services related to dwelling"

lab val HSFUEL HSFUEL
label var HSFUEL "Expenditure on firewood charcoal and other fuel"

lab val GAS GAS
label var GAS "Expenditure on gas for cooking"

lab val ELEC ELEC
label var ELEC "Expenditure on electricity"

lab val HSKEROSENE HSKEROSENE
label var HSKEROSENE "Expenditure on kerosine"

lab val HSDIESEL HSDIESEL
label var HSDIESEL "Expenditure on diesel"

lab val HSUTILITY HSUTILITY
label var HSUTILITY "Expenditure on electricity and gas (rowtoal of GAS and ELEC)"

lab val TOTHOUS TOTHOUS
label var TOTHOUS "Total expenditure on housing"

order HID RURURB RENT_ACT RENT_IMP HSREPAIR HSWATER HSFUEL GAS ELEC HSKEROSENE HSDIESEL HSUTILITY TOTHOUS

des /*number of observations is 21,595 (households)*/

sort HID

save "04_AGGDATA\04_ETH_EXPHOUS", replace







