clear
set more off
set mem 500m

*Generating 05_ETH_EXPFURN.dta*

cd "C:\AFRCE\Ethiopia 2004"
use "02_CLEANDATA\HICES\cons2004_ict.dta", clear

des  /*initial number of observations is 1,813,186*/

sort HID

codebook HID  /*21,595 households*/

/*NOTE: First thing to do in this dataset is to recode the UR variable to match
the code of the same variable in the demographic_con2004 dataset. This allows for a 
successful merging of the datasets*/

recode UR 1=2 2=1
lab def UR 1"rural" 2 "urban", replace
lab val UR UR

tab UR
tab UR,nol

*Generating HSFURNI variable*
*--------------------------------
gen HSFURNI=EXPEN if [CQ15>=40101 & CQ15<=40198] | [CQ15>=41001 & CQ15<=41002] | [CQ15==41012|CQ15==41024|CQ15==41005|CQ15==40907]

*Generating HSTEXTIL variable*
*-------------------------------
gen HSTEXTIL=EXPEN if CQ15>=40201 & CQ15<=40298

*Generating HSAPPLIAN variable*
*---------------------------------
gen HSAPPLIAN=EXPEN if [CQ15>=40301 & CQ15<=40308] | [CQ15>=40313 &  CQ15<=40398] | [CQ15==41004|CQ15==41015] | CQ15==40510
replace HSAPPLIAN=EXPEN if CQ15==41003

*Generating HSUTENSIL variable*
*---------------------------------
gen HSUTENSIL=EXPEN if [CQ15>=40401 & CQ15<=40509] | [CQ15>=40512 & CQ15<=40740] | [CQ15>=40754 & CQ15<=40906] | [CQ15==40909|CQ15==40998] | [CQ15==41006|CQ15==41044] | [CQ15==41098]

*Generating HSTOOLS variable*
*------------------------------
gen HSTOOLS=EXPEN if CQ15==40745

*Generating HSSERV variable*
*------------------------------
gen HSSERV=EXPEN if [CQ15>=41201 & CQ15<=41213] | [CQ15>=41301 & CQ15<=41398]
replace HSSERV=EXPEN if [CQ15>=41217 & CQ15<=41221] 

collapse (sum)HSFURNI HSTEXTIL HSAPPLIAN HSUTENSIL HSTOOLS HSSERV, by (HID)

sort HID

des /*21,595 observations*/
*------------------------------------------------------------------------------------------------------
*Merging above variables with BASICINFO dataset*
*--------------------------------------------------
merge HID using "04_AGGDATA\00_ETH_BASICINFO.dta", keep (RURURB)
tab _merge /*_merge=3 (21,595 observations)*/
drop _merge

des /*21,595 observations*/

*Annualizing the variables*
*-----------------------------
*expenditure values are already annualized in the dataset*

*Generating TOTHOUS variable*
*----------------------------
egen TOTFURN =rowtotal(HSFURNI HSTEXTIL HSAPPLIAN HSUTENSIL HSTOOLS HSSERV)

*Labeling the variables*
*------------------------
lab val HSFURNI HSFURNI
label var HSFURNI "Expenditure on furniture and furnishings"

lab val HSTEXTIL HSTEXTIL
label var HSTEXTIL "Expenditure on household textiles"

lab val HSAPPLIAN HSAPPLIAN
label var HSAPPLIAN "Expenditure on household appliances"

lab val HSUTENSIL HSUTENSIL
label var HSUTENSIL "Expenditure on glassware, tableware, kitchenware, and household utensils"

lab val HSTOOLS HSTOOLS
label var HSTOOLS "Expenditure on household and garden tools and equipment" 

lab val HSSERV HSSERV
label var HSSERV "Expenditure on goods of routine household maintenance"

lab val TOTFURN TOTFURN
label var TOTFURN "Total expenditure on furnishing"

order HID RURURB HSFURNI HSTEXTIL HSAPPLIAN HSUTENSIL HSTOOLS HSSERV TOTFURN

des /*number of observations is 21,595 (households)*/

sort HID

save "04_AGGDATA\05_ETH_EXPFURN", replace





