clear
set more off
set mem 500m

*Generating 07_ETH_EXPTRSP.dta*

cd "C:\AFRCE\Ethiopia 2004"
use "02_CLEANDATA\HICES\cons2004_ict.dta", clear

des  /*initial number of observations is 1,813,186*/

sort HID
codebook HID  /*21,595 households*/

/*NOTE: First thing to do in this dataset is to recode the UR variable to match
the code of the same variable in the demographic_con2004 dataset. This allows for 
a successful merging of the datasets*/

recode UR 1=2 2=1
lab def UR 1"rural" 2 "urban", replace
lab val UR UR

tab UR
tab UR,nol

*Generating VEHICLES variable*
*--------------------------------
gen VEHICLES=EXPEN if [CQ15>=60101|CQ15==60102|CQ15==60104]

*Generating TRFUEL variable*
*------------------------------
gen TRFUEL=EXPEN if CQ15==60105 

*Generating TRPERSON variable*
*--------------------------------
gen TRPERSON=EXPEN if [CQ15==60103|[CQ15>=60106 & CQ15<=60198]]

*Generating TRSERVE*
*----------------------
gen TRSERVE=EXPEN if [CQ15>=60201 & CQ15<=60298]

collapse(sum)VEHICLES TRFUEL TRPERSON TRSERVE, by (HID)

des /*number of observations is 21,595*/
*-----------------------------------------------------------------------------------------

*Merging above variables with BASICINFO dataset*
*--------------------------------------------------
sort HID
merge HID using "04_AGGDATA\00_ETH_BASICINFO.dta", keep (RURURB)
tab _merge /*_merge=3 (21,595 observations)*/
drop _merge

des /*21,595 observations*/

*Annualizing the variables*
*-----------------------------
*expenditure values are already annualized in the dataset*

*Generating TOTTRSP variable*
*-------------------------------
egen TOTTRSP =rowtotal(TRFUEL TRPERSON TRSERVE)

*Labeling the variables*
*-------------------------
lab val VEHICLES VEHICLES
label var VEHICLES "Purchase of vehicles"

lab val TRFUEL TRFUEL
label var TRFUEL "Expenditure on fuels for transportation such as petrol,diesel,etc.."

lab val TRPERSON TRPERSON
label var TRPERSON "Expenditure on personal transport equipment/repairs/chauffeurs etc."

lab val TRSERVE TRSERVE
label var TRSERVE "Expenditure on public transportation/airfare etc."

lab val TOTTRSP TOTTRSP
label var TOTTRSP "Total expenditure on transport"

order HID RURURB VEHICLES TRFUEL TRPERSON TRSERVE TOTTRSP

des /*number of observations is 21,595*/

sort HID

save "04_AGGDATA\07_ETH_EXPTRSP", replace



