clear
set more off
set mem 500m

/*Generating 08_ETH_EXPCMNQ.dta*/

cd "C:\AFRCE\Ethiopia 2004"
use "02_CLEANDATA\HICES\cons2004_ict.dta", clear

des  /*initial number of observations is 1,813,186*/

sort HID

codebook HID  /*21,595 households*/

/*NOTE: First thing to do in this dataset is to recode the UR variable to match 
the code of the same variable in the demographic_con2004 dataset. This allows for a 
successful merging of the datasets*/

recode UR 1=2 2=1
lab def UR 1"rural" 2 "urban", replace
lab val UR UR

tab UR
tab UR,nol

*Generating COMPOST variable*
*-----------------------------
gen COMPOST=EXPEN if [CQ15==61001|CQ15==61002]

*Generating COMTEL variable*
*-----------------------------
gen COMTEL=EXPEN if [CQ15==61101|CQ15==61102]

*Generating COMSERVE variable*
*--------------------------------
gen COMSERVE=EXPEN if CQ15>=61103 & CQ15<=61298

collapse(sum)COMPOST COMTEL COMSERVE, by (HID)

des /*number of observations is 21,595*/
*-----------------------------------------------------------------------------------------

*Merging above variables with BASICINFO dataset*
*------------------------------------------------
sort HID
merge HID using "04_AGGDATA\00_ETH_BASICINFO.dta", keep (RURURB)
tab _merge /*_merge=3 (21,595 observations)*/
drop _merge

des /*21,595 observations*/

*Annualizing the variables*
*---------------------------
*expenditure values are already annualized in the dataset*

*Generating TOTTRSP variable*
*-------------------------------
egen TOTCMNQ =rowtotal(COMPOST COMTEL COMSERVE)

*Labeling the variables*
*---------------------------
lab val COMPOST COMPOST
label var COMPOST "Expenditure on postal services"

lab val COMTEL COMTEL
label var COMTEL "Expenditure on telephone and telefax services"

lab val COMSERVE COMSERVE
label var COMSERVE "Expenditure on telephone, telefax and internet services"

lab val TOTCMNQ TOTCMNQ
label var TOTCMNQ "Total expenditure on communication"

order HID RURURB COMPOST COMTEL COMSERVE TOTCMNQ

des /*number of observations is 21,595 (hosueholds)*/

sort HID

save "04_AGGDATA\08_ETH_EXPCMNQ", replace









