clear
set more off
set mem 500m

*Generating 09_ETH_EXPRCRE.dta*

cd "C:\AFRCE\Ethiopia 2004"
use "02_CLEANDATA\HICES\cons2004_ict.dta", clear

des  /*initial number of observations is 1,813,186*/

sort HID

codebook HID  /*21,595 households*/

/*NOTE: First thing to do in this dataset is to recode the UR variable to 
match the code of the same variable in the demographic_con2004 dataset. This allows 
for a successful merging of the datasets*/

recode UR 1=2 2=1
lab def UR 1"rural" 2 "urban", replace
lab val UR UR

tab UR
tab UR,nol

*Generating RCAUDI variable*
*------------------------------
gen RCAUDI=EXPEN if CQ15==40310 | [CQ15>=70105 & CQ15<=70198] | [CQ15==70203|CQ15==70213] | [CQ15==70202]

*Generating RCPETS variable*
*------------------------------
gen RCPETS=EXPEN if [CQ15==70101]

*Generating RCSERVE*
*----------------------
gen RCSERVE=EXPEN if [CQ15>=70208 & CQ15<=70212] | [CQ15==70214|CQ15==70215] | [CQ15==70217|CQ15==70218|CQ15==70298]

*Generating RCNEWS*
*---------------------
gen RCNEWS=EXPEN if [CQ15==70301|CQ15==70302|CQ15==70398]

*Generating RCHOLID variable*
*-------------------------------
gen RCHOLID=EXPEN if CQ15==70216

collapse(sum)RCAUDI RCPETS RCSERVE RCNEWS RCHOLID, by (HID)

des /*number of observations is 21,595*/
*--------------------------------------------------------------------------------------

*Merging variables with file 00_ETH_BASICINFO*
*------------------------------------------------
sort HID
merge HID using 04_AGGDATA\00_ETH_BASICINFO, keep (RURURB)
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge

*Generating DURRC*
*------------------
gen DURRC=.

*Annualizing the data*
*------------------------
*expenditure values are already annualized in the dataset*

*Generating TOTRCRE*
*----------------------
egen TOTRCRE =rowtotal(RCAUDI RCPETS RCSERVE RCNEWS RCHOLID)

*Labeling the variables*
*---------------------------
lab val RCAUDI RCAUDI
label var RCAUDI "Expenditure on audio-visual, photographic and information processing equipment"

lab val DURRC DURRC
label var DURRC "Expenditure on other major durables for recreation and culture"

lab val RCPETS RCPETS
label var RCPETS "Expenditure on other recreational items and equipment, gardens and pets"

lab val RCSERVE RCSERVE
label var RCSERVE"Expenditure on recreational and cultural services, such as movies etc."

lab val RCNEWS RCNEWS
label var RCNEWS "Expenditure on newspapers, books and stationary of non-educational purpose"

lab val RCHOLID RCHOLID
label var RCHOLID "Expenditure on package holidays"

lab val TOTRCRE TOTRCRE
label var TOTRCRE "Total expenditure on recreation"

order HID RURURB RCAUDI DURRC RCPETS RCSERVE RCNEWS RCHOLID

des /*number of observations is 21,595 (households)*/

sort HID

save "04_AGGDATA\09_ETH_EXPRCRE", replace


