clear
set more off
set mem 500m

*Generating 10_ETH_EXPeduc.dta*

cd "C:\AFRCE\Ethiopia 2004"
use "02_CLEANDATA\HICES\cons2004_ict.dta", clear

des  /*initial number of observations is 1,813,186*/

sort HID

codebook HID  /*21,595 households*/

/*NOTE: First thing to do in this dataset is to recode the UR variable
to match the code of the same variable in the demographic_con2004 dataset.This 
allows for a successful merging of the datasets*/

recode UR 1=2 2=1
lab def UR 1"rural" 2 "urban", replace
lab val UR UR

tab UR
tab UR,nol

*Generating EDUNDEFIN variable*
*--------------------------------
gen EDUNDEFIN=EXPEN if CQ15>=72001 & CQ15<=72098

*Generating FEES variable*
*----------------------------
gen FEES=EXPEN if CQ15>=72101 & CQ15<=72898

collapse EDUNDEFIN FEES, by (HID)

des /*21,595 observations (households)*/
*------------------------------------------------------------------------------------------

*Merging variable from file 00_ETH_BASICINFO*
*---------------------------------------------
sort HID
merge HID using  04_AGGDATA\00_ETH_BASICINFO, keep (RURURB)
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge

*Generating EDPRIMAR variable*
*--------------------------------
gen EDPRIMAR=.

*Generating EDSECOND variable*
*--------------------------------
gen EDSECOND=.

*Generating EDPOSTSEC variable*
*--------------------------------
gen EDPOSTSEC=.

*Generating EDTERTIAR variable*
*--------------------------------
gen EDTERTIAR=.

*Annualizing variables*
*------------------------
*expenditure values are already annualized in the dataset*

*Generating TOTEDUC variable*
*-----------------------------
egen TOTEDUC=rowtotal(EDPRIMAR EDSECOND EDPOSTSEC EDTERTIAR EDUNDEFIN FEES)

*Labeling the variables*
*-------------------------
lab val EDPRIMAR EDPRIMAR
label var EDPRIMAR "Expenditure on pre-primary and primary education"

lab val EDSECOND EDSECOND
label var EDSECOND "Expenditure on secondary education"

lab val EDPOSTSEC EDPOSTSEC
label var EDPOSTSEC "Expenditure on post-secondary but non-tertiary education"

lab val EDTERTIAR EDTERTIAR
label var EDTERTIAR "Expenditure on tertiary education"

lab val EDUNDEFIN EDUNDEFIN
label var EDUNDEFIN "Expenditure on education cannot be defined"

lab val FEES FEES
label var FEES "Expenditure on education fees"

lab val TOTEDUC TOTEDUC
label var TOTEDUC "Total expenditure on education"

order HID RURURB EDPRIMAR EDSECOND EDPOSTSEC EDTERTIAR EDUNDEFIN FEES TOTEDUC

des /*number of observations is 21,595 (households)*/

sort HID

save "04_AGGDATA\10_ETH_EXPEDUC", replace








