clear
set more off
set mem 500m

/*Generating 12_ETH_EXPMISC.dta*/

cd "C:\AFRCE\Ethiopia 2004"
use "02_CLEANDATA\HICES\cons2004_ict.dta", clear

des  /*initial number of observations is 1,813,186*/

sort HID

codebook HID  /*21,595 households*/

/*NOTE: First thing to do in this dataset is to recode the UR variable 
to match the code of the same variable in the demographic_con2004 dataset.This allows
for a successful merging of the datasets*/

recode UR 1=2 2=1
lab def UR 1"rural" 2 "urban", replace
lab val UR UR

tab UR
tab UR,nol

*Generating MISPERSN variable*
*------------------------------
gen MISPERSN=EXPEN if CQ15==41214|CQ15==41215|CQ15==41216
replace MISPERSN=EXPEN if CQ15>=41227 & CQ15<=41298
replace MISPERSN=EXPEN if CQ15>=80101 & CQ15<=80104
replace MISPERSN=EXPEN if CQ15>=80107
replace MISPERSN=EXPEN if CQ15>=80112 & CQ15<=80198
replace MISPERSN=EXPEN if CQ15>=80301 & CQ15<=80398

*Generating MISPEREFF variable*
*--------------------------------
gen MISPEREFF=EXPEN if [CQ15==30408|CQ15==30409|CQ15==30411]
replace MISPEREFF=EXPEN if [CQ15==41010|CQ15==41011|CQ15==41014]
replace MISPEREFF=EXPEN if [CQ15==80105|CQ15==80106]
replace MISPEREFF=EXPEN if CQ15>=80108 & CQ15<=80111
replace MISPEREFF=EXPEN if CQ15>=80201 & CQ15<=80298

*Generating MISSPROT variable*
*--------------------------------
gen MISSPROT=EXPEN if CQ15==90320

*Generating MISINSUR variable*
*------------------------------
gen MISINSUR=EXPEN if CQ15==90304

*Generating MISFINAN variable*
*--------------------------------
gen MISFINAN=EXPEN if CQ15>=90101 & CQ15<=90198

*Generating MISOTHER variable*
*------------------------------
gen MISOTHER=EXPEN if CQ15>=90201 & CQ15<=90208
replace MISOTHER=EXPEN if CQ15==90211
replace MISOTHER=EXPEN if CQ15>=90213 & CQ15<=90298
replace MISOTHER=EXPEN if CQ15==90301
replace MISOTHER=EXPEN if CQ15>=90307 & CQ15<=90319
replace MISOTHER=EXPEN if [CQ15==90321|CQ15==90398]
replace MISOTHER=EXPEN if CQ15==90209
replace MISOTHER=EXPEN if CQ15==90210

collapse (sum) MISPERSN MISPEREFF MISSPROT MISINSUR MISFINAN MISOTHER, by (HID)

des/*Number of observations is 21,595*/
*------------------------------------------------------------------------------------

*Merging variable from file 00_ETH_BASICINFO*
*---------------------------------------------
sort HID
merge HID using 04_AGGDATA\00_ETH_BASICINFO, keep (RURURB)
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge

*Generating MISPROST variable*
*-------------------------------
gen MISPROST=. /*NOTE:No item related to this variable was found in CQ15*/

*Annualizing variables*
*-----------------------
*expenditure values are already annualized in the dataset*

*Generating TOTMISC variable*
*--------------------------------
egen TOTMISC=rowtotal(MISPERSN MISPROST MISPEREFF MISSPROT MISINSUR MISFINAN MISOTHER)

*Labeling the variables*
*-------------------------
lab val MISPROST MISPROST
label var MISPROST "Expenditure on prostitution"

lab val MISPEREFF MISPEREFF
label var MISPEREFF "Expenditure on personal effects not mentioned elsewhere"

lab val MISSPROT MISSPROT
label var MISSPROT "Expenditure on social protection"

lab val MISINSUR MISINSUR
label var MISINSUR "Expenditure on insurance, including housing,health etc."

lab val MISFINAN MISFINAN
label var MISFINAN "Expenditure on fianancial services"

lab val MISOTHER MISOTHER
label var MISOTHER "Total expenditure on other services not mentioned elsewhere"

lab val MISPERSN MISPERSN
label var MISPERSN "Total expenditure on personal care"

lab val TOTMISC TOTMIS
label var TOTMISC "Total miscelleneous expenditure"

order HID RURURB MISPERSN MISPROST MISPEREFF MISSPROT MISINSUR MISFINAN MISOTHER TOTMISC

des /*number of observations is 21,595 (households)*/

sort HID

save "04_AGGDATA\12_ETH_EXPMISC", replace





