clear
set mem 100m

*Generating ETH_2004_E.dta*
cd "C:\AFRCE\Ethiopia 2004\04_AGGDATA"

use 00_ETH_BASICINFO,clear
keep HID REGION RURURB HHSIZE HHSIZE_S

sort HID
merge HID using 01_ETH_EXPFOOD 
tab _merge
drop _merge

sort HID
merge HID using 02_ETH_EXPALCH
tab _merge
drop _merge

sort HID
merge HID using 03_ETH_EXPCLTH
tab _merge
drop _merge

sort HID
merge HID using 04_ETH_EXPHOUS
tab _merge
drop _merge

sort HID
merge HID using 05_ETH_EXPFURN
tab _merge
drop _merge

sort HID
merge HID using 06_ETH_EXPHLTH
tab _merge
drop _merge

sort HID
merge HID using 07_ETH_EXPTRSP
tab _merge
drop _merge

sort HID
merge HID using 08_ETH_EXPCMNQ
tab _merge
drop _merge

sort HID
merge HID using 09_ETH_EXPRCRE
tab _merge
drop _merge

sort HID
merge HID using 10_ETH_EXPEDUC
tab _merge
drop _merge

sort HID
merge HID using 11_ETH_EXPHOTL
tab _merge
drop _merge

sort HID
merge HID using 12_ETH_EXPMISC
tab _merge
drop _merge

*---------------------------------------------------------------------------------------------------
*FDPINDEX varaible*
*--------------------
*datasets for Ethiopia 2004 do not have a variable capturing the regional food price deflators*
*Therefore, 14_ETH_2004_E.dta will not contain "FDPINDEX" variable*
*---------------------------------------------------------------------------------------------------
sort HID

*Generating HHEXP_N*
*--------------------
egen HHEXP_N = rowtotal (TOTFOOD TOTALCH TOTCLTH TOTHOUS TOTFURN TOTHLTH TOTTRSP TOTCMNQ TOTRCRE TOTEDUC TOTHOTL TOTMISC)

*Generating HHEXP_R*
*--------------------
*HHEXP_R will not be generated since FDPINDEX is not available*
*gen HHEXP_R = HHEXP_N/FDPINDEX*

*Generating TOTFDAL*
*---------------------
egen TOTFDAL= rowtotal(TOTFOOD TOTALCH)
lab val TOTFDAL TOTFDAL
lab var TOTFDAL "Sum of TOTFOOD and TOTALCH"

*Generating TOTNFD*
*-------------------
egen TOTNFD=rowtotal(TOTCLTH TOTHOUS TOTFURN TOTHLTH TOTTRSP TOTCMNQ TOTRCRE TOTEDUC TOTHOTL TOTMISC)
lab val TOTNFD TOTNFD
lab var TOTNFD "Sum of all non-food expenditures"

*Generating CPI2005_DEF*
*------------------------
*CPI 2005=277.5653; CPI 2004(survey year CPI)=259.7911*

gen CPI2005_DEF = 277.5653/259.7911
lab val CPI2005_DEF CPI2005_DEF
lab var CPI2005_DEF "CPI to deflate/inflate HHEXP_N to 2005 local prices"

*Generating PPP2005*
*--------------------
gen PPP2005=2.75
lab val PPP2005 PPP2005
lab var PPP2005 "2005 PPP exchange rate to 2005 local currency"

*------------------------------------------------------------------------------------------------------
*Labeling the variables*
*------------------------
lab var TOTMISC "Total expnditures on miscellaneous goods and services"

lab val HHEXP_N HHEXP_N
label var  HHEXP_N"Total annual nominal household expenditures"

*lab val HHEXP_R  HHEXP_R*
*label var HHEXP_R"Total annual real household expenditure"*

*lab val FDPINDEX FDPINDEX*
*lab var FDPINDEX "Regional food price deflators"*

*----------------------------------------------------------------------------------------------------
keep HID REGION RURURB HHSIZE HHSIZE_S TOTFOOD TOTALCH TOTFDAL TOTCLTH HSUTILITY HSFUEL GAS ELEC ///
	HSKEROSENE HSDIESEL TOTHOUS TOTFURN TOTHLTH TRFUEL TRPERSON TRSERVE TOTTRSP TOTCMNQ TOTRCRE TOTEDUC ///
	TOTHOTL TOTMISC TOTNFD /*FDPINDEX*/ HHEXP_N /*HHEXP_R*/ CPI2005_DEF PPP2005 ///

order HID REGION RURURB HHSIZE HHSIZE_S TOTFOOD TOTALCH TOTFDAL TOTCLTH HSUTILITY HSFUEL GAS ELEC ///
	HSKEROSENE HSDIESEL TOTHOUS TOTFURN TOTHLTH TRFUEL TRPERSON TRSERVE TOTTRSP TOTCMNQ TOTRCRE TOTEDUC ///
	TOTHOTL TOTMISC TOTNFD /*FDPINDEX*/ HHEXP_N /*HHEXP_R*/ CPI2005_DEF PPP2005 ///
	
*converting observations coded as missing to zero for all variables*
*--------------------------------------------------------------------
mvencode _all,mv(0) override 

count /*Total number of observations = 21,595*/

sort HID
save "ETH_2004_E.dta", replace

						