
*Standardized Household Level File*
*___________________________________
                 
*Generating ETH_2004_H.dta*
*--------------------------- 

*Section 3.1:Sample,Geography and Basic Household Identifier*
*--------------------------------------------------------------

clear
set more off
set mem 500m

cd "C:\AFRCE\Ethiopia 2004"
use "02_CLEANDATA\HICES\demographic_con2004.dta",clear

des /*initial number of observations is 99,229*/

sort HID
codebook HID /*21,595 households*/

*Generating DISTRICT variable*
*--------------------------------
gen DISTRICT=C1Q4
lab val DISTRICT DISTRICT
lab var  DISTRICT "District code"

*Generating PROVINCE variable*
*-------------------------------
gen PROVINCE=C1Q3
lab val PROVINCE PROVINCE
lab var PROVINCE "Province code"

keep HID DISTRICT PROVINCE

sort HID

collapse DISTRICT PROVINCE,by (HID)

des  /*21,595 observations (households)*/

*Merging with 00_ETH_BASICINFO.dta*
*-----------------------------------
sort HID
merge HID using 04_AGGDATA\00_ETH_BASICINFO.dta, keep (COUNTRY REGION SURVEYR RURURB HHSIZE HHSIZE_S WTA_HH WTA_POP)
tab _merge /*_merge=3 (21,595 observations)*/
drop _merge

des /*21,595 observations (households)*/

sort HID

save "04_AGGDATA\ETH_2004_H.dta", replace
*--------------------------------------------------------------------------------------------

*Section 3.2:Household Head Characteristics*
*---------------------------------------------

use 04_AGGDATA\ETH_2004_I, clear

des /*99,229 observations*/

keep HID SEX AGEY MARSTAT EDLEVEL_AR HEAD 
drop if HEAD!=1
drop HEAD

des /*21,594 observations*/

rename SEX HHSEX
rename AGEY HHAGEY
rename MARSTAT HHMARST
rename EDLEVEL_AR HHEDLEV

lab var HHSEX "Sex of household head"
lab var HHAGEY "Age of household head"
lab var HHMARST "Marital status of household head"
lab var HHEDLEV "Education level of household head"

sort HID

*Merging with 04_AGGDATA\ETH_2004_H.dta*
*----------------------------------------
merge HID using 04_AGGDATA\ETH_2004_H.dta

tab _merge  /*_merge=2 (1 observation), _merge=3 (21,594 observations)*/
drop _merge

sort HID

save 04_AGGDATA\ETH_2004_H.dta, replace

*NOTE:THERE IS NO LABOR FILE FOR eth_2004.Therefore, labor information for HHH cannot be captured
*-------------------------------------------------------------------------------------------------

*Section 3.3:Housing and Utilities*
*-----------------------------------
use "02_CLEANDATA\WMS\Household Assests.dta", clear

des  /*36,302 observations*/

sort HID
codebook HID  /*21,595 households*/


*Generating OWNHOUSE variable*
*------------------------------
recode w7q15a 2=0
gen OWNHOUSE=w7q15a
lab val OWNHOUSE
lab def OWNHOUSE 1 "yes" 0 "no"
lab var OWNHOUSE "Ownership of dwelling unit"

collapse OWNHOUSE, by (HID)

*Merging with 04_AGGDATA\ETH_2004_H.dta*
*-----------------------------------------
sort HID
merge HID using 04_AGGDATA\ETH_2004_H.dta
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge

des /*21,595 observations (households)*/
sort HID
save 04_AGGDATA\ETH_2004_H.dta, replace
*-------------------------------------------------------------------------------------------

use "02_CLEANDATA\WMS\Housing Ammenities.dta"

des /*21,595 observations*/

sort HID
codebook HID /*21,595 households*/


*Generating ROOMS variable*
*---------------------------
gen	ROOMS=w5q17a	
lab var ROOMS "Number of habitable rooms"

*Generating ROOF variable*
*---------------------------
gen ROOF=.
replace ROOF=2 if w5q19a==3 
*above category in "roof" variable includes roof made out of mud as well since in w5q19a wood and mud roofs are aggrgated together to form w5q19a==3*
replace ROOF=3 if w5q19a==4 
*above category in "roof" variable includes roof made out of reed as well since in w5q19a bamboo and reed roofs are aggrgated together to form w5q19a==4*
replace ROOF=9 if [w5q19a==1|w5q19a==2|w5q19a==5|w5q19a==6]
lab val ROOF ROOF
lab def ROOF 1 " Concrete/cement/brick/stone" 2 "Wood" 3 "Bamboo/thaTch" 4 "Tiles/shingles" 5 "Tin/metal sheets" 6 "Makeshift" 9 "other",replace
lab var ROOF "Main material used for roof"	

*Generating WALLS variable*
*---------------------------
gen WALLS=.
replace WALLS=1 if [w5q18a==4|w5q18a==5|w5q18a==7]
*above category also includes mud since w5q18a=4 aggregates mud with stone*
replace WALLS=2 if [w5q18a==1|w5q18a==2]
*above category in "walls" variable includes wood aggregated with grass and stone since in w5q18a variable the wood is aggregated with other materials*
replace WALLS=9 if 	[w5q18a==3|w5q18a==6|w5q18a==8]				
lab val WALLS WALLS
lab def ROOF 1 " Concrete/cement/brick/stone" 2 "Wood" 3 "Bamboo/thach" 4 "Iron/metal sheets" 5 "Clay/mud" 6 "Makeshift" 9 "other",replace
lab var WALLS "Main material used for external walls"					
					
*Generating FLOOR variable*
*---------------------------
gen FLOOR=.
lab val FLOOR FLOOR
lab def FLOOR 1 "Cement/tiles/marble" 2 "Wood/Bamboo" 3 "Vinyl" 4 "Earth/clay/mud" 9 "Other"
lab var FLOOR "Main material used for floor"

*Generating WATER variable*
*---------------------------
*NOTE:dataset contains source of drinking water in both wet and dry season. "WATER" variable will be derived from soure of drinking water in dry season (w5q25a) because most of Ethiopia's regions have dry season*
gen WATER=.
replace WATER=1 if [w5q25a==1|w5q25a==2]
replace WATER=2 if [w5q25a==3|w5q25a==4]
replace WATER=4 if w5q25a==5
replace WATER=5 if w5q25a==6
replace WATER=6 if w5q25a==7
lab val WATER WATER
lab def WATER 1 "Pipe (own tap)" 2 "Public standpipe" 3 "Borehole" 4 "Wells(protected)" 5 "Wells(unprotected)" 6 "Surface water" 7 "Rain water" 8 "Vendor/truck" 9 "Other"
lab var WATER "Main source of water"

keep HID ROOMS ROOF WALLS FLOOR WATER 

*Merging with 04_AGGDATA\ETH_2004_H.dta*
*----------------------------------------
sort HID
merge HID using "04_AGGDATA\ETH_2004_H.dta"
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge

des /*21,595 observations (households)*/
sort HID
save "04_AGGDATA\ETH_2004_H.dta", replace
*-----------------------------------------------------------------

use "02_CLEANDATA\WMS\Types of Facilities.dta"

des /*532,771 observations*/

codebook HID /*21,595 households*/
sort HID

*Generating ADISWAT variable*
*-----------------------------
*NOTE:dataset contains drinking water in both wet and dry season. "ADISWAT" variable will be derived from drinking water in dry season (w6q13=12) because most of Ethiopia's regions have dry season*/

gen ADISWAT=w6q15a if w6q13==12	
lab val ADISWAT ADISWAT
lab var ADISWAT "Actual distance to main water point (kms)"

*Generating ATIMWAT variable*
*-----------------------------
*NOTE:dataset contains drinking water in both wet and dry season. "ATIMWAT" variable will be derived from drinking water in dry season (w6q13=12) because most of Ethiopia's regions have dry season*/

gen ATIMWAT=w6q15c if w6q13==12	
lab val ATIMWAT ATIMWAT
lab var ATIMWAT "Actual time taken to main water point (mins)"

collapse ADISWAT ATIMWAT, by (HID)

*Generating ELECTCON variable*
*-------------------------------
gen ELECTCON=.
lab val ELECTCON ELECTCON
lab def ELECTCON 1 "Central/local" 2 "Solar/wind" 3 "Generator" 9 "Other" 0 "None"
lab var ELECTCON "Connection of electricity in dwelling"

*Merging with 04_AGGDATA\ETH_2004_H.dta*
*----------------------------------------
sort HID
merge HID using 04_AGGDATA\ETH_2004_H.dta
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge

des /*21,595 observations (households)*/
sort HID
save 04_AGGDATA\ETH_2004_H.dta, replace
*------------------------------------------------------

use "02_CLEANDATA\WMS\Housing Ammenities.dta"

des /*21,595 observations*/

sort HID
codebook HID /*21,595 households*/

*Generating FUELCOOK variable*
*------------------------------
gen FUELCOOK=.
replace FUELCOOK=1 if [w5q22a==1|w5q22a==2]
replace FUELCOOK=2 if w5q22a==4
replace FUELCOOK=3 if w5q22a==3
replace FUELCOOK=4 if w5q22a==6
replace FUELCOOK=5 if w5q22a==5
replace FUELCOOK=9 if w5q22a==7
*w5q22a==8 not included in fuelcook==9 because w5q22a==8 is "no source of cooking fuel used now"*
lab val FUELCOOK FUELCOOK
lab def FUELCOOK 1 "Firewood" 2 "Kerosene" 3 "Charcoal" 4 "Electricity" 5 "Gas" 9 "Other"
lab var FUELCOOK "Main cooking fuel"

*Generating FUELLIGH variable*
*------------------------------
gen FUELLIGH=.
replace FUELLIGH=1 if [w5q20a==2|w5q20a==3]
replace FUELLIGH=2 if w5q20a==1
replace FUELLIGH=3 if w5q20a==5
replace FUELLIGH=9 if [w5q20a==4|w5q20a==6]
lab val FUELLIGH FUELLIGH
lab def FUELLIGH 1 "Electricity" 2 "Kerosene" 3 "Candles" 4 "Gas" 9 "Other"
lab var FUELLIGH "Main lighting fuel"

*Generating TOILET variable*
*-----------------------------
gen TOILET=.
replace TOILET=1 if [w5q28a==1|w5q28a==2]
replace TOILET=3 if [w5q28a==3|w5q28a==4]
replace TOILET=9 if [w5q28a==5|w5q28a==6|w5q28a==7]
lab val TOILET TOILET
lab def TOILET 1 "Flush toilet" 2 "Improved pit latrine" 3 "Pit latrine" 4 "No facility" 9 "Other"
lab var TOILET "Main toilet facility"

*Generating GARBDISP variable*
*--------------------------------
gen GARBDISP=.
replace GARBDISP=1 if [w5q29a==1|w5q29a==2]
replace GARBDISP=2 if [w5q29a==3|w5q29a==6]
replace GARBDISP=3 if w5q29a==4
replace GARBDISP=9 if [w5q29a==5|w5q29a==7]
lab val GARBDISP GARBDISP
lab def GARBDISP 1 "Collected" 2 "Buried/burned" 3 "Discarded in empty lots,street,rivers" 9 "Other"
lab var GARBDISP "Garbage and trash disposal"

keep HID FUELCOOK FUELLIGH TOILET GARBDISP

*Merging with 04_AGGDATA\ETH_2004_H.dta*
*------------------------------------------
sort HID
merge HID using "04_AGGDATA\ETH_2004_H.dta"
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge

des /*21,595 observations (households)*/
sort HID
save "04_AGGDATA\ETH_2004_H.dta", replace
*-----------------------------------------------------------------

use "02_CLEANDATA\WMS\Types of Facilities.dta"

des /*532,771 observations*/

codebook HID /*21,595 households*/
sort HID

*Generating DISPSCH variable*
*------------------------------
gen DISPSCH=w6q15a if w6q13==1
lab val DISPSCH DISPSCH
lab var DISPSCH "Distance to nearest elementary/primary school (kms)"
 
*To check if DISPSCH was generated correctly*
tab w6q15a  if w6q13==1
tab DISPSCH

*Generating DISPSCH1 variable*
*--------------------------------
*NOTE:distance measure in the dataset has no decimals, therefore,the cut-off points used in generating dispsch1 is different from what is stated in the reference mannual.*
*However, the variable is coded according to the reference manual to keep harmony with other surveys*
 
tab w6q15a if w6q13==1 /*use result from tabulation to generate DISPSCH1*/

gen DISPSCH1=1 if [w6q15a==0|w6q15a==1] & w6q13==1
replace DISPSCH1=2 if w6q15a>2 & w6q13==1
replace DISPSCH1=3 if w6q15a>5 & w6q13==1
replace DISPSCH1=4 if w6q15a>10 & w6q13==1
replace DISPSCH1=5 if w6q15a>11 & w6q13==1
lab val DISPSCH1 DISPSCH1
lab def DISPSCH1 1 "Outside dwelling and up to 1 km" 2 ">1-2 km" 3 ">2-5 km" 4 ">5-10 km" 5 "Over 10 km" 9 "Undefined"
lab var DISPSCH1 "Distance to nearest elementary school"

*Generating TIMPSCH variable*
*------------------------------
gen TIMPSCH=w6q15c if w6q13==1
lab val TIMPSCH TIMPSCH
lab var TIMPSCH "Time taken to nearest elementary/primary school (mins)"
 
*Generating TIMPSCH1 variable*
*--------------------------------
tab w6q15b  if w6q13==1 

gen TIMPSCH1=1 if w6q15c<=30 & w6q13==3 
replace TIMPSCH1=2 if w6q15c>30 & w6q15c<=60 & w6q13==3  
replace TIMPSCH1=3 if w6q15b>6 & w6q13==3 
replace TIMPSCH1=4 if w6q15b>12 & w6q13==3 
replace TIMPSCH1=5 if w6q15b>13 & w6q13==3 
lab val TIMPSCH1 TIMPSCH1
lab def TIMPSCH1 1 "Within 1/2 hour" 2 ">1/2 to 1 hour away" 3 ">1 to 6 hrs" 4 ">6 to 12 hrs" 5 "Over 12 hrs" 9 "Undefined"
lab var TIMPSCH1 "Time taken to nearest elementary/primary school"

*Generating DISHEAL variable*
*-----------------------------
gen DISHEAL=w6q15a if w6q13==3 
lab val DISHEAL DISHEAL
lab var DISHEAL "Distance to nearest health facility (kms)"

*NOTE:Dataset contains health post, clinic, health center, and hospital. Since health post is the lowest level, health post is taken to represent health facility*

*Checking if DISHEAL was generated correctly*/
tab w6q15a if w6q13==3 

*Generating DISHEAL1 variable*
*------------------------------
*NOTE:distance measure in the dataset has no decimals, therefore,the cut-off points used in generating dispsch1 is different from what is stated in the reference mannual.*
*However, the variable is coded according to the reference manual to keep harmony with other surveys*

tab w6q15a  if w6q13==3 

gen DISHEAL1=1 if [w6q15a==0|w6q15a==1] & w6q13==3 
replace DISHEAL1=2 if w6q15a>2 & w6q13==3 
replace DISHEAL1=3 if w6q15a>5 & w6q13==3 
replace DISHEAL1=4 if w6q15a>10 & w6q13==3 
replace DISHEAL1=5 if w6q15a>11 & w6q13==3 
lab val DISHEAL1 DISHEAL1
lab def DISHEAL1 1 "Outside dwelling and up to 1 km" 2 ">1-2 km" 3 ">2-5 km" 4 ">5-10 km" 5 "Over 10 km"  10 "Undefined"
lab var DISHEAL1 "Distance to nearest health facility"

*Generating TIMHEAL variable*
*------------------------------
*NOTE:Dataset contains health post, clinic, health center, and hospital. Since health post is the lowest level, health post is taken to represent health facility*

gen TIMHEAL=w6q15c if w6q13==3 
lab val TIMHEAL TIMHEAL
lab var TIMHEAL "Time taken to nearest health facility (mins)"

*Generating TIMHEAL1 variable*
*-------------------------------
*NOTE:Dataset contains health post, clinic, health center, and hospital. Since health post is the lowest level, health post is taken to represent health facility*

tab w6q15b  if w6q13==3 

gen TIMHEAL1=1 if w6q15c<=30 & w6q13==3 
replace TIMHEAL1=2 if w6q15c>30 & w6q15c<=60 & w6q13==3 
replace TIMHEAL1=3 if w6q15b>6 & w6q13==3 
replace TIMHEAL1=4 if w6q15b>12 & w6q13==3 
replace TIMHEAL1=5 if w6q15b>13 & w6q13==3 
lab val TIMHEAL1 TIMHEAL1
lab def TIMHEAL1 1 "Within 1/2 hour" 2 ">1/2 to 1 hour away" 3 ">1 to 6 hrs" 4 ">6 to 12 hrs" 5 "Over 12 hrs" 9 "Undefined"
lab var TIMHEAL1 "Time taken to nearest health facility"

collapse DISPSCH DISPSCH1 TIMPSCH TIMPSCH1 DISHEAL DISHEAL1 TIMHEAL TIMHEAL1, by (HID)

*Merging above variableith 04_AGGDATA\ETH_2004_H.dta*
*-------------------------------------------------------
sort HID
merge HID using "04_AGGDATA\ETH_2004_H.dta"
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge

des /*21,595 observations (households)*/
sort HID
save "04_AGGDATA\ETH_2004_H.dta", replace
*------------------------------------------------------------------------

*Section 3.4: Ownership of Durable and Non-Durable Goods*					
*-----------------------------------------------------------

use "02_CLEANDATA\WMS\Household Assests.dta", clear

des  /*21,595 observations*/

*dataset is at the HH level*

codebook HID /*21,595 households*/
				
*Generating AGLAND variable*
*------------------------------
*Dataset does not explicitly have a variable which indicates the type of land a HH owns*
*However, dataset has "w1q11" variable which is defined as whether the HH is an agricultural holder"
*Therefore, assume that a HH which is an agricultural holder and owns land, this land is agricultural in type*
*Similarly assume that a HH which is a non-agricultural holder and owns land, this land is non-agricultural in type*

gen AGLAND=.
replace AGLAND=1 if w1q11==1 & w7q17a==1
replace AGLAND=3 if w1q11==2 & w7q17a==1
lab val AGLAND AGLAND
lab def AGLAND 1 "Yes" 2 "Cannot be determined" 3 "No",replace
lab var AGLAND "Ownership of agricultural land"

*Generating AGLNDOW variable*
*-------------------------------
*w7q20b is "land area in standard unit". Assume this unit is hectares as there is no indication from the questionnaire or dataset on the precise definition of the unit*

gen AGLNDOW=.
replace AGLNDOW=w7q20b if w1q11==1 & w7q17a==1
replace AGLNDOW=0 if AGLAND==3
lab val AGLNDOW AGLDNOW 
lab var AGLNDOW "Agricultural land owned by household(ha)"

*Generating OTHLNDOW variable*
*-------------------------------
gen OTHLNDOW=.
replace OTHLNDOW=w7q20b if w1q11==2 & w7q17a==1
lab val OTHLNDOW OTHLNDOW
lab var OTHLNDOW "Non-agricultural land owned by household (ha)"

keep HID AGLAND AGLNDOW OTHLNDOW

*Merging with 04_AGGDATA\ETH_2004_H.dta*
*------------------------------------------
sort HID
merge HID using 04_AGGDATA\ETH_2004_H.dta
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge

des /*21,595 observations (households)*/
sort HID
save "04_AGGDATA\ETH_2004_H.dta", replace

*Generating LANDSIZE variable*
*-------------------------------
egen LANDSIZE= rowtotal (AGLNDOW OTHLNDOW)
lab val LANDSIZE LANDSIZE
lab var LANDSIZE "Land size owned by household (ha)"

*Generating AREA_IRRIG variable*
*---------------------------------
gen AREA_IRRIG=.
lab val AREA_IRRIG AREA_IRRIG
lab var AREA_IRRIG "Area of irrigated agricultural land (ha)"

*Generating AREA_NONIRRIG variable*
*-------------------------------------
gen AREA_NONIRRIG=.
lab val AREA_NONIRRIG AREA_NONIRRIG
lab var AREA_NONIRRIG "Area of non-irrigated agricultural land (ha)"

*Generating AREA_COLLAT variable*			
*-----------------------------------
gen AREA_COLLAT=.
lab val AREA_COLLAT AREA_COLLAT
lab var AREA_COLLAT "Total plot areas can be used as collateral for loan(ha)"

*Generating LANDCON variable*
*------------------------------
gen LANDCON=.
lab val LANDCON LANDCON
lab var LANDCON "Conflict about the land"

des /*21,595 observations (households)*/
sort HID
save 04_AGGDATA\ETH_2004_H.dta, replace
*------------------------------------------------------------

use "02_CLEANDATA\WMS\Household Other assets.dta", clear

des  /*617,913 observations*/

*dataset is at the asset level*

codebook HID /*21,595 households*/

*Generating RADIO variable*
*-----------------------------
tab w7q29 if w7q27==18
tab w7q29 if w7q27==18,nol

gen RADIO=.
replace RADIO=1 if w7q29==1 & w7q27==18
replace RADIO=0 if w7q29==2 & w7q27==18
lab val RADIO RADIO
lab def RADIO 1 "Yes" 0 "No",replace
lab var RADIO "Ownership of radio"

*Generating TV variable*
*-------------------------
tab w7q29 if w7q27==19
tab w7q29 if w7q27==19,nol

gen TV=.
replace TV=1 if w7q29==1 & w7q27==19
replace TV=0 if w7q29==2 & w7q27==19
lab val TV TV
lab def TV 1 "Yes" 0 "No",replace
lab var TV "Ownership of television"

collapse RADIO TV, by (HID)

*Merging with 04_AGGDATA\ETH_2004_H.dta*
*---------------------------------------------------------
sort HID
merge HID using 04_AGGDATA\ETH_2004_H.dta
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge


*Generating PHONE variable*
*------------------------------
*NOTE:PHONE variable is coded as missing because the dataset lumps landline and cell phones together*

gen PHONE=.
lab val PHONE PHONE
lab def PHONE 0 "No" 1 "Yes"
lab var PHONE "Ownership of landline (fixed) phone"

*Generating CPHONE variable*
*------------------------------
*NOTE:CPHONE variable is coded as missing because the dataset  lumps landline and cell phones together*

gen CPHONE=.
lab val CPHONE CPHONE
lab def CPHONE 0 "No" 1 "Yes"
lab var CPHONE "Ownership of at least one cellular phone"

*Generating INTERNET variable*
*--------------------------------
gen INTERNET=.
lab val INTERNET INTERNET
lab def INTERNET 0 "No" 1 "Yes"
lab var INTERNET "Access to internet"

des /*21,595 observations (households)*/
sort HID
save 04_AGGDATA\ETH_2004_H.dta, replace
*---------------------------------------------------------------------------------

use "02_CLEANDATA\WMS\Household Other assets.dta", clear

des  /*617,913 observations*/

*dataset is at the asset level*

codebook HID /*21,595 households*/

*Generating FRIDGE variable*
*-----------------------------
tab w7q29 if w7q27==27
tab w7q29 if w7q27==27,nol

gen FRIDGE=.
replace FRIDGE=1 if w7q29==1 & w7q27==27
replace FRIDGE=0 if w7q29==2 & w7q27==27
lab val FRIDGE FRIDGE
lab def FRIDGE 0 "No" 1 "Yes" 
lab var FRIDGE "Ownership of fridge"  

*Generating SEWMACH variable*
*-------------------------------
tab w7q29 if w7q27==25
tab w7q29 if w7q27==25,nol

gen SEWMACH=1 if w7q29==1 & w7q27==25
replace SEWMACH=0 if w7q29==2 & w7q27==25
lab val SEWMACH SEWMACH
lab def SEWMACH 1 "Yes" 0 "No"
lab var SEWMACH "Ownership of sewing machine"  

collapse FRIDGE SEWMACH, by (HID)

*Merging with 04_AGGDATA\ETH_2004_H.dta*
*----------------------------------------
sort HID
merge HID using 04_AGGDATA\ETH_2004_H.dta
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge

*Generating COMPUTER variable*
*-------------------------------
gen COMPUTER=.
lab val COMPUTER COMPUTER
lab def COMPUTER 0 "No" 1 "Yes"
lab var COMPUTER "Ownership of computer"

des /*21,595 observations (households)*/
sort HID
save 04_AGGDATA\ETH_2004_H.dta, replace
*---------------------------------------------------------------------------------

use "02_CLEANDATA\WMS\Household Other assets.dta", clear

des  /*617,913 observations*/

*dataset is at the asset level*

codebook HID /*21,595 households*/
		
*Generating STOVE variable*
*-----------------------------
tab w7q29 if w7q27==12
tab w7q29 if w7q27==12,nol

gen STOVE=1 if w7q29==1 & w7q27==12
replace STOVE=0 if w7q29==2 & w7q27==12
lab val STOVE STOVE
lab def STOVE 1 "Yes" 0 "No"
lab var STOVE "Ownership of stove"  			
					
*Generating OXCART variable*
*-----------------------------
tab w7q29 if w7q27==24
tab w7q29 if w7q27==24,nol

gen OXCART=1 if w7q29==1 & w7q27==24
replace OXCART=0 if w7q29==2 & w7q27==24
lab val OXCART OXCART
lab def OXCART 1 "Yes" 0 "No"
lab var OXCART "Ownership of animal cart" 

*Generating BCYCLE variable*
*------------------------------
tab w7q29 if w7q27==23
tab w7q29 if w7q27==23,nol

gen BCYCLE=1 if w7q29==1 & w7q27==23
replace BCYCLE=0 if w7q29==2 & w7q27==23
lab val BCYCLE BCYCLE
lab def BCYCLE 1 "Yes" 0 "No"
lab var BCYCLE "Ownership of bicycle" 
	
collapse STOVE OXCART BCYCLE, by (HID)
	
*Merging with 04_AGGDATA\ETH_2004_H.dta*
*-------------------------------------------
sort HID
merge HID using 04_AGGDATA\ETH_2004_H.dta
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge

*Generating BOAT variable*
*----------------------------
gen BOAT=.
lab val BOAT BOAT
lab def BOAT 0 "No" 1 "Yes"
lab var BOAT "Ownership of boat"

*Generating MCYCLE variable*
*-----------------------------
gen MCYCLE=.
lab val MCYCLE MCYCLE
lab def MCYCLE 0 "No" 1 "Yes"
lab var MCYCLE "Ownership of motorcycle"

*Generating CAR variable*
*---------------------------
 *NOTE: "CAR" is coded as missing because the dataset lumps private and commerical cars together*/

gen CAR=.
lab val CAR CAR
lab def CAR 0 "No" 1 "Yes"
lab var CAR "Ownership of private car"

des /*21,595 observations (households)*/
sort HID
save 04_AGGDATA\ETH_2004_H.dta, replace
*--------------------------------------------------------------
use "02_CLEANDATA\WMS\Household Other assets.dta", clear

des  /*617,913 observations*/

*dataset is at the asset level*

codebook HID /*21,595 households*/

*Generating LLIVESK variable*
*--------------------------------
gen LLIVESK=.
replace LLIVESK=w7q30 if w7q27==1
lab var LLIVESK "Number of large-sized livestock owned"

*Generating MLIVESK variable*
*-------------------------------
gen MLIVESK=.
replace MLIVESK=w7q30 if w7q27==5
lab var MLIVESK "Number of medium-sized livestock owned"

*Generating POULTRY variable*
*------------------------------
gen POULTRY=.
replace POULTRY=w7q30 if w7q27==6
lab var POULTRY "Number of poultry owned"

collapse LLIVESK MLIVESK POULTRY, by (HID)

*Merging with 04_AGGDATA\ETH_2004_H.dta*
*------------------------------------------
sort HID
merge HID using 04_AGGDATA\ETH_2004_H.dta
tab _merge  /*_merge=3 (21,595 observations)*/
drop _merge

des /*21,595 observations (households)*/
sort HID
save 04_AGGDATA\ETH_2004_H.dta, replace
*--------------------------------------------------------------------------------------------------------

*Section 3.5: Household Expenditure*		
*--------------------------------------
use "04_AGGDATA\ETH_2004_E.dta", clear

des  /*21,595 observations*/

*Generating PCEXP variable*
*-----------------------------
gen PCEXP=HHEXP_N/HHSIZE
lab val PCEXP PCEXP
lab var PCEXP "Per capita annual food and non-food consumption expenditure in national currency, not regionally deflated"

*Generating PCEXPDR variable*
*------------------------------
*In the case of Ethiopia 2004 dataset, food expenditure cannot be adjusted regionally due to non-availability of price deflator*
*However, non-food expenditures are not regionally adjusted since rural and urban prices of non-food items are assumed to be the same across regions*

*Generating Per-capita Food Expenditures*
*-----------------------------------------
gen PC_TOTFDAL=TOTFDAL/HHSIZE
lab val PC_TOTFDAL PC_TOTFDAL
lab var PC_TOTFDAL "Per capita food expenditures"

*Cleaning Per-capita Food Expenditures*
*----------------------------------------
egen Z_PC_TOTFDAL=std(PC_TOTFDAL)
bysort REGION RURURB:egen MD_PC_TOTFDAL=median(PC_TOTFDAL)
replace PC_TOTFDAL=MD_PC_TOTFDAL if Z_PC_TOTFDAL>3
drop Z_PC_TOTFDAL MD_PC_TOTFDAL
*if value is greater than 3 std dev, then it is replace by median value*

*Generating Per-capita Non-food Expenditures*
*---------------------------------------------
gen PC_TOTNFD=TOTNFD/HHSIZE
lab val PC_TOTNFD PC_TOTNFD
lab var PC_TOTNFD "Per capita non-food expenditures"

*Cleaning Per-capita Non-food Expenditures*
*----------------------------------------------
egen Z_PC_TOTNFD=std(PC_TOTNFD)
bysort REGION RURURB:egen MD_PC_TOTNFD=median(PC_TOTNFD)
replace PC_TOTNFD=MD_PC_TOTNFD if Z_PC_TOTNFD>3
drop Z_PC_TOTNFD MD_PC_TOTNFD

*Generating PCEXP_PPP*
*-----------------------
gen PCEXP_PPP=PCEXP*CPI2005_DEF*(1/PPP2005)

*CPI2005_DEF=CPI2005/CPI2004(Survey Year)*
/*CPI2005=277.5653,CPI 2004(survey year CPI)=259.7911, 2005 PPP Exchange rate as per ICP Global Results=2.75*/

lab val  PCEXP_PPP  PCEXP_PPP
lab var  PCEXP_PPP "Per capita annual food and non-food cons. expend in real terms and 2005 $PPP"

drop PC_TOTFDAL PC_TOTFDAL PC_TOTNFD

keep HID PCEXP PCEXP_PPP

sort HID

des  /*21,595 observations*/

merge HID using "04_AGGDATA\ETH_2004_H.dta"
tab _merge   /*_merge=3 (21,595 observations)*/
drop _merge

*Generating QUINTILE_N variable*
*---------------------------------
xtile QUINTILE_N=PCEXP_PPP[aw=WTA_POP],nq(5)
lab val QUINTILE_N QUINTILE_N
lab var QUINTILE_N "Income quintiles at the national level"

*Generating QUINTILE_RU variable*
*----------------------------------
xtile QUINTILE_RUR=PCEXP_PPP if RURURB==1[aw=WTA_POP],nq(5)
xtile QUINTILE_URB=PCEXP_PPP if RURURB==2[aw=WTA_POP],nq(5)
gen QUINTILE_R_U=QUINTILE_RUR if RURURB==1
replace QUINTILE_R_U=QUINTILE_URB if RURURB==2
lab val QUINTILE_R_U QUINTILE_R_U
label var QUINTILE_R_U" Expenditure quintiles by rural/urban"

sort HID

save "04_AGGDATA\ETH_2004_H.dta",replace
*---------------------------------------------------------------------
			
*Section 3.6: Household Remittances*
*-------------------------------------

use "04_AGGDATA\ETH_2004_H.dta", clear

des /*21,595 observations*/

codebook HID  /*21,595 households*/
				  			  
*Generating SEX_RMT_1 variable*
*--------------------------------
gen SEX_RMT_1=. 
lab val SEX_RMT_1 SEX_RMT_1
lab def SEX_RMT_1 1 "Male" 0 "Female"
lab var SEX_RMT_1 "Sex of the 1st remittance sending member"

*Generating SEX_RMT_2 variable*
*---------------------------------
gen SEX_RMT_2=.
lab val SEX_RMT_2 SEX_RMT_2
lab def SEX_RMT_2 1 "Male" 0 "Female"
lab var SEX_RMT_2 "Sex of the 2nd remittance sending member"

*Generating SEX_RMT_3 variable*
*---------------------------------
gen SEX_RMT_3=.
lab val SEX_RMT_3 SEX_RMT_3
lab def SEX_RMT_3 1 "Male" 0 "Female"
lab var SEX_RMT_3 "Sex of the 3rd remittance sending member"

*Generating RELAT_RMT_1 variable*
*------------------------------------
gen RELAT_RMT_1 =.
lab val RELAT_RMT_1 RELAT_RMT_1
lab def RELAT_RMT_1 2 "Spouse" 3 "Son/daughter" 4 "Parents/grandparents" 5 "Grandchild" 6 "Son/daughter-in-law" 7 "Siblings and other relative"
lab var RELAT_RMT_1 "Relationship to the household head of the 1st remittance sending member"

*Generating RELAT_RMT_2 variable*
*------------------------------------
gen RELAT_RMT_2 =.
lab val RELAT_RMT_2 RELAT_RMT_2
lab def RELAT_RMT_2 2 "Spouse" 3 "Son/daughter" 4 "Parents/grandparents" 5 "Grandchild" 6 "Son/daughter-in-law" 7 "Siblings and other relative"
lab var RELAT_RMT_2 "Relationship to the household head of the 2nd remittance sending member"

*Generating RELAT_RMT_3 variable*
*----------------------------------
gen RELAT_RMT_3 =.
lab val RELAT_RMT_3 RELAT_RMT_3
lab def RELAT_RMT_3 2 "Spouse" 3 "Son/daughter" 4 "Parents/grandparents" 5 "Grandchild" 6 "Son/daughter-in-law" 7 "Siblings and other relative"
lab var RELAT_RMT_3 "Relationship to the household head of the 3rd remittance sending member"

*Generating DES_MIG_1 variable*
*---------------------------------
gen DES_MIG_1=.
lab val DES_MIG_1 DES_MIG_1
lab def DES_MIG_1 1 "Capital" 2 "Within the country (but not capital" 3 "Abroad"
lab var DES_MIG_1 "Destination of migration of the 1st remittance sending member"

*Generating DES_MIG_2 variable*
*--------------------------------
gen DES_MIG_2=.
lab val DES_MIG_2 DES_MIG_2
lab def DES_MIG_2 1 "Capital" 2 "Within the country (but not capital" 3 "Abroad"
lab var DES_MIG_2 "Destination of migration of the 2nd remittance sending member"

*Generating DES_MIG_3 variable*
*--------------------------------
gen DES_MIG_3=.
lab val DES_MIG_3 DES_MIG_3
lab def DES_MIG_3 1 "Capital" 2 "Within the country (but not capital" 3 "Abroad"
lab var DES_MIG_3 "Destination of migration of the 3rd remittance sending member"

*Generating ORIGIN_RMT variable*
*---------------------------------
gen ORIGIN_RMT=.
lab val ORIGIN_RMT ORIGIN_RMT
lab def ORIGIN_RMT 1 "Domestic"2 "Abroad" 3 "Both"
lab var  ORIGIN_RMT "Origin of the remittances"

*Generating AMT_RMT_1 variable*
*---------------------------------
gen AMT_RMT_1=.
lab val AMT_RMT_1 AMT_RMT_1
lab var AMT_RMT_1 "Amount of annual remittance by the 1st remittance sending member"

*Generating AMT_RMT_2 variable*
*-------------------------------
gen AMT_RMT_2=.
lab val AMT_RMT_2 AMT_RMT_2
lab var AMT_RMT_2 "Amount of annual remittance by the 2nd remittance sending member"

*Generating AMT_RMT_3 variable*
*---------------------------------
gen AMT_RMT_3=.
lab val AMT_RMT_3 AMT_RMT_3
lab var AMT_RMT_3 "Amount of annual remittance by the 3rd remittance sending member"

*Generating INC_RMT*
*----------------------
gen INC_RMT=.
lab val INC_RMT INC_RMT
lab var INC_RMT "Total amount of annual remittances received from remittance sending members"

sort HID

des /* 21,595 observations*/
save "04_AGGDATA\ETH_2004_H.dta",replace
*----------------------------------------------------------------------------------

*Section 3.7: Household Income Variables*
*-----------------------------------------

use "04_AGGDATA\ETH_2004_H.dta", clear

des /*21,595 observations*/

codebook HID  /*21,595 households*/

*Generating INC_WAGE variable*
*-------------------------------
gen INC_WAGE=. 
lab val INC_WAGE INC_WAGE
lab var INC_WAGE "Wage and salaries (annual)"

*Generating INC_SOCA variable*
*-------------------------------
gen INC_SOCA=. 
lab val INC_SOCA INC_SOCA
lab var INC_SOCA "Bonus and social allowances derived from wage jobs (annual)"

*Generating INC_FARM_G*
*------------------------
gen INC_FARM_G=.
lab val INC_FARM_G INC_FARM_G
lab var INC_FARM_G "Gross income from household farm businesses (annual)"

*Generating INC_NFARM_G variable*
*---------------------------------
gen INC_NFARM_G=.
lab val INC_NFARM_G INC_NFARM_G
lab var INC_NFARM_G "Gross income from household nonfarm businesses (annual)"

*Generating INC_RENT variable*
*-------------------------------
gen INC_RENT=.
lab val INC_RENT INC_RENT
lab var INC_RENT "Rental income (annual)" 

*Generating INC_FIN variable*
*------------------------------
gen INC_FIN=.
lab val INC_FIN INC_FIN
lab var INC_FIN "Financial income (annual)"

*Generating INC_PEN variable*
*-----------------------------
gen INC_PEN=.
lab val INC_PEN INC_PEN
lab var INC_PEN "Pensions/social assistance (annual)"

*Generating INC_STUDY variable*
*--------------------------------
gen INC_STUDY=.
lab val INC_STUDY INC_STUDY
lab var INC_STUDY "Study support (annual)"

*Generating INC_OTH variable*
*------------------------------
gen INC_OTH=.
lab val INC_OTH INC_OTH
lab var INC_OTH "Other income (annual)"

*Generating INC_TOT_G variable*
*-------------------------------
egen INC_TOT_G=rowtotal (INC_RMT INC_WAGE INC_SOCA INC_FARM_G INC_NFARM_G INC_RENT INC_FIN INC_PEN INC_STUDY INC_OTH)
lab val INC_TOT_G INC_TOT_G
lab var INC_TOT_G "Total gross household income (annual)"

keep COUNTRY REGION PROVINCE DISTRICT HID SURVEYR RURURB HHSIZE HHSIZE_S WTA_HH ///
	WTA_POP HHSEX HHAGEY HHMARST HHEDLEV /*HHEMSTAT HHEMPTYPE HHINDUSTRY*/ OWNHOUSE ROOMS ///
	ROOF WALLS FLOOR WATER ADISWAT ATIMWAT ELECTCON FUELCOOK FUELLIGH TOILET GARBDISP DISPSCH ///
	DISPSCH1 TIMPSCH TIMPSCH1 DISHEAL DISHEAL1 TIMHEAL TIMHEAL1 AGLAND AGLNDOW OTHLNDOW LANDSIZE ///
	AREA_IRRIG AREA_NONIRRIG AREA_COLLAT LANDCON RADIO TV PHONE CPHONE INTERNET FRIDGE SEWMACH ///
	COMPUTER STOVE OXCART BCYCLE BOAT MCYCLE CAR LLIVESK MLIVESK POULTRY PCEXP PCEXP_PPP ///
	QUINTILE_N QUINTILE_RU QUINTILE_URB QUINTILE_R_U SEX_RMT_1 SEX_RMT_2 SEX_RMT_3 RELAT_RMT_1 ///
	RELAT_RMT_2 RELAT_RMT_3 DES_MIG_1 DES_MIG_2 DES_MIG_3 ORIGIN_RMT AMT_RMT_1 AMT_RMT_2 ///
	AMT_RMT_3 INC_RMT INC_WAGE INC_SOCA INC_FARM_G INC_NFARM_G INC_RENT INC_FIN INC_PEN ///
	INC_STUDY INC_OTH INC_TOT_G ///

order COUNTRY REGION PROVINCE DISTRICT HID SURVEYR RURURB HHSIZE HHSIZE_S WTA_HH ///
	WTA_POP HHSEX HHAGEY HHMARST HHEDLEV /*HHEMSTAT HHEMPTYPE HHINDUSTRY*/ OWNHOUSE ROOMS ///
	ROOF WALLS FLOOR WATER ADISWAT ATIMWAT ELECTCON FUELCOOK FUELLIGH TOILET GARBDISP DISPSCH ///
	DISPSCH1 TIMPSCH TIMPSCH1 DISHEAL DISHEAL1 TIMHEAL TIMHEAL1 AGLAND AGLNDOW OTHLNDOW LANDSIZE ///
	AREA_IRRIG AREA_NONIRRIG AREA_COLLAT LANDCON RADIO TV PHONE CPHONE INTERNET FRIDGE SEWMACH ///
	COMPUTER STOVE OXCART BCYCLE BOAT MCYCLE CAR LLIVESK MLIVESK POULTRY PCEXP PCEXP_PPP ///
	QUINTILE_N QUINTILE_RU QUINTILE_URB QUINTILE_R_U SEX_RMT_1 SEX_RMT_2 SEX_RMT_3 RELAT_RMT_1 ///
	RELAT_RMT_2 RELAT_RMT_3 DES_MIG_1 DES_MIG_2 DES_MIG_3 ORIGIN_RMT AMT_RMT_1 AMT_RMT_2 ///
	AMT_RMT_3 INC_RMT INC_WAGE INC_SOCA INC_FARM_G INC_NFARM_G INC_RENT INC_FIN INC_PEN ///
	INC_STUDY INC_OTH INC_TOT_G ///

des /*21,595 households*/

sort HID
save "04_AGGDATA\ETH_2004_H.dta",replace








				  
