*HARMONIZED INDIVIDUAL-LEVEL FILE*
*_________________________________

*Generating ETH_2000_I.dta*
*----------------------------

*Section 1.1: Sample, Geography and Basic Household Identifier*
*----------------------------------------------------------------

clear
set more off
set mem 500m
						
cd "C:\AFRCE\Ethiopia 2004"
use "02_CLEANDATA\HICES\demographic_con2004.dta",clear
						
des  /*Initial number of observations (individuals) is 99,229*/

sort HID
codebook HID /*21,595 households*/

*Generating DISTRICT variable*
*------------------------------
gen DISTRICT=C1Q4
lab val DISTRICT DISTRICT
lab var  DISTRICT "District code"

*Generating PROVINCE variable*
*-------------------------------
gen PROVINCE=C1Q3
lab val PROVINCE PROVINCE
lab var PROVINCE "Province code"

keep HID DISTRICT PROVINCE

sort HID

collapse DISTRICT PROVINCE,by (HID)

des  /*21,595 observations (households)*/

*Merging with 00_ETH_BASICINFO.dta*
*-------------------------------------
sort HID
merge HID using 04_AGGDATA\00_ETH_BASICINFO.dta, keep (COUNTRY REGION SURVEYR RURURB HHSIZE HHSIZE_S WTA_HH WTA_POP)
tab _merge /*_merge=3 (21,595 observations)*/
drop _merge

des /*21,595 observations (households)*/

sort HID

save "04_AGGDATA\ETH_2004_I.dta", replace
*------------------------------------------------------------------------------

*Section 1.2: Generating Basic Demographic Characteristics*
*-----------------------------------------------------------

use "02_CLEANDATA\HICES\demographic_con2004.dta",clear

des  /*number of initial observations is 99,229*/

sort HID
codebook HID  /*21,595 observations (households)*/

/*NOTE: First thing to do in this dataset is to recode the C1Q2 variables to match
the code of the same variables in the cons2004_ict dataset which led 
to 04_AGGDATA\00_ETH_BASICINFO. This is a necessary step to allow for a successful
merging of the datasets*/

recode C1Q2 13=8 14=9 15=10
lab val C1Q2 C1Q2
lab def C1Q2 1 "Tigray" 2 "Afar" 3 "Amhara" 4 "Oromiya" 5 "Somale" 6 " Benshinangul-Gumuz" 7 "S.N.N.P.R.G." 8 "Harari" 9 "Addis Ababa" 10 "Dire Dawa", replace

/*Checking*/
tab C1Q2
tab C1Q2,nol

*Renaming variable d1q13 to INDID*
*-----------------------------------
rename d1q13 INDID
lab val INDID INDID
label var INDID "Individual identification"

*Checking if only HHH is assigned an individual ID of 1*
tab INDID d1q15,m
*result of cross-tabulation shows that only household head has INDID=1*
*cross tabulation also shows that there are 21,593 HHHs with INDID=1*
*cross tabulation also shows that there is a HHH whose INDID==.*
br HID if d1q15==0 & INDID==.  /*shows HID=15010110301102008*/

*Assigning HHH with missing INDID a value of 1 as individual ID*
replace INDID=1 if INDID==. & d1q15==0  /*1 real change made*/
tab INDID d1q15,m
*above cross-tabulation shows 21,594 HHHs with INDID=1*

*Up to this stage, there are 21,595 households and 21,594 HHHs*

*Generating SEX variable*
*--------------------------
recode d1q16 (2=0)
gen SEX=d1q16
lab val SEX SEX
lab def SEX 1 "Male" 0 "Female",replace
lab var SEX "Sex"

*Generating RELAT variable*
*---------------------------
*First check if there are mutilple household heads in a household*
sort HID
bysort HID:egen multiplehhh=count (d1q15) if d1q15==0
tab multiplehhh /*shows no multiple household heads*/
drop multiplehhh

*NOTE: no grandchild is identified in dataset*
gen RELAT=1 if d1q15==0
replace RELAT=2 if d1q15==1
replace RELAT=3 if [d1q15==2|d1q15==3|d1q15==4] /*assumption: assume that son/daughter of spouse is also son/daughter of household head*/ 
replace RELAT=4 if d1q15==5 
*no "grandchild" identified in dataset so there is no relat==5*
*no son/daughter-in-law identified in dataset so there is no relat==6*
replace RELAT=7 if [d1q15==6| d1q15==7] /*brother/sister of head/spouse will be under "other relative" category*/ 
replace RELAT=8 if [d1q15==8|d1q15==9]
replace RELAT=9 if d1q15==10

lab val RELAT RELAT
lab def RELAT 1 "Head" 2 "Spouse" 3 "Child" 4 "Father/Mother" 5 "Grandchild" 6 "Son-in-law/daughter-in-law" 7 "Other relative" 8 "Domestic help/paying boarder" 9 "Non-relative"
lab var RELAT "Relationship to household head"

*Generating HEAD variable*
*----------------------------
gen HEAD=0 if [d1q15==1|d1q15==2|d1q15==3|d1q15==4|d1q15==5|d1q15==6|d1q15==7|d1q15==8|d1q15==9|d1q15==10]
replace HEAD=1 if d1q15==0
lab val HEAD HEAD
lab def HEAD 0 "No" 1 "Yes"
lab var HEAD "Household head"

*Generating marstat variable*
*-----------------------------
*Checking for presence of multiple spouses in a household*
bysort HID:egen marriedmultiple=count (d1q15) if d1q15==1 /*counting for presence of more than one spouse in the household*/
*above command assigns the values only to spouse*
*Assigning marriedmultiple value also for each HHH in a HH which has a spouse*
egen marriedmultiple1=mean(marriedmultiple) if [d1q15==0|d1q15==1],by (HID) 

tab marriedmultiple /*shows that there are some households having 2,3,5,6 spouses*/
codebook HID if marriedmultiple==1 /*13,157 households with 1 spouse in each household*/
codebook HID if marriedmultiple==2 /*74 households with 2 spouses in each household*/
codebook HID if marriedmultiple==3 /*3 households with 3 spouses in each household*/
codebook HID if marriedmultiple==5 /*1 households with 5 spouses in each household*/
codebook HID if marriedmultiple==6 /*1 households with 6 spouses in each household*/

*Cross tabulating to see if there is any inconsistency between d1q15 (relationship to household head) and d1q21 (marital status)*/

tab d1q15 d1q21 /*shows there are 134 spouses who are never married, 9 spouses divorced, 4 spouses separated, 4 spouses widowed*/
browse HID d1q16 d1q17 d1q15 d1q21  marriedmultiple if d1q15==1 & d1q21==1

/*Cleaning the inconsistencies between marital status and relationship to head of household
by changing the martial status of spouses who are reported as other than married to married.
*This cleaning step is required before generating MARSTAT variable*/

replace d1q21=2 if d1q15==1 & d1q21==1 /*changing spouse never married to spouse married (134 changes made)*/
replace d1q21=2 if d1q15==1 & d1q21==3 /*changing spouse divorced to spouse married (9 changes made)*/
replace d1q21=2 if d1q15==1 & d1q21==4 /*changing spouse separated to spouse married (4 changes made)*/
replace d1q21=2 if d1q15==1 & d1q21==5 /*changing spouse separated to spouse married (4 changes made)*/

tab d1q15 d1q21 /*to check if cleaning between marital status and relationship to head of household was done correctly*/

gen MARSTAT=1 if d1q21==1
replace MARSTAT=2 if d1q21==2 & marriedmultiple1==1
replace MARSTAT=3 if d1q21==2 & [marriedmultiple1==2|marriedmultiple1==3|marriedmultiple1==5|marriedmultiple1==6]
replace MARSTAT=5 if [d1q21==3|d1q21==4]
replace MARSTAT=6 if d1q21==5

lab val MARSTAT MARSTAT
lab def MARSTAT 1 "Never married" 2 "Married monogamous" 3 "Married polygamous" 4 "Common law,union coutumiere,union libre,living together" 5 "Divorced/Separated" 6 "Widowed"
lab var MARSTAT "Marital status"

*Generating SP_PRES variable*
*-------------------------------
gen SP_PRES=.
lab val SP_PRES SP_PRES
lab var SP_PRES "Spouse present"

*Generating AGEY variable*
*------------------------------
*NOTE: age variable is only given in years and not months so checking for consistency with age in months to get correct age in completed years is not possible*/

gen AGEY=d1q17
lab val AGEY AGEY
label var AGEY "Age in completed years"

*Generating ETHNICITY variable*
*-------------------------------
gen ETHNICITY=.
lab val ETHNICITY ETHNICITY
label var ETHNICITY "Ethnicity"
  
*Generating LANGUAGE variable*
*-------------------------------
gen LANGUAGE=.
lab val LANGUAGE LANGUAGE
label var LANGUAGE "Language"

*Generating RELIGION variable*
*------------------------------
gen RELIGION=.
lab val RELIGION RELIGION
lab var RELIGION "Religion"

keep HID INDID SEX RELAT HEAD MARSTAT SP_PRES AGEY ETHNICITY LANGUAGE RELIGION

sort HID
merge HID using "04_AGGDATA\ETH_2004_I.dta"
tab _merge /*_merge=3 (99,229 observations)*/
drop _merge

des  /*99,229 observations*/

sort HID INDID

save "04_AGGDATA\ETH_2004_I.dta", replace
*----------------------------------------------------------------------------------------

*Section 1.3: Literacy and Education*
*--------------------------------------

use "02_CLEANDATA\WMS\Member Characterstics and Child Nutrition.dta", clear

des /*98,265 observations (individuals)*/

sort HID
codebook HID /*21,595 households*/

*Renaming variable w1q13 to INDID*
*----------------------------------
rename w1q13 INDID
lab val INDID INDID
label var INDID "Individual identification"

sort HID INDID
merge HID INDID using "04_AGGDATA\ETH_2004_I.dta", keep (AGEY)
tab _merge /*_merge=1 (73,012 observations), _merge=2 (1,515 observations), _merge=3 (97,714 observations)*/
drop if _merge==1  /*dropped these observations because these are individuals that have information on education but are not in the main individual dataset which has the individual characteristics*/
drop _merge

count /*99,229 observations*/

*Generating LITERACY variable*
*-------------------------------
*NOTE:There is no literacy variable in the dataset that is for can read OR write. Instead the dataset contains a variable w2q15 which is can read AND write*
*NOTE: Inorder to avoid losing valuable information, w2q15 is used as a result to generate literacy variable*

tab w1q17 w2q15  /*shows that only individuals aged 5 or more have information on LITERACY*/

gen LITERACY=w2q15 
lab val LITERACY LITERACY
lab def LITERACY 1 "Can read & write" 2 "Cannot read or write" 3 "Cannot be determined",replace
lab var LITERACY "Literacy status"

*Generating EVERATTD variable*
*-------------------------------
*checking for observations age<5 and included in the w2q17 variable. Result is no observations*
browse w2q17 if w1q17<5 & w2q17!=. 

tab w2q17,m /*13,788 missing observations*/

*Indivduals currently attending school should be included in EVERATTD=1*
*However, in this dataset, there is no explicit variable which captures whether an individual is currently attending school*
*Instead, there is another variable w2q20 defined as "registered to attend formal education this year"*
*Assume individuals registered to attend formal education this year will be currently attending school and include them with EVERATTD=1*

gen EVERATTD=.
replace EVERATTD=1 if [w2q17==1|w2q20==1] & AGEY>=5
replace EVERATTD=0 if w2q17==2 & AGEY>=5
lab val EVERATTD EVERATTD
lab def EVERATTD 1 "Yes" 0 "No",replace
lab var EVERATTD "Ever attended school"

*Generating ATSCHOOL variable*
*------------------------------
browse w2q20 if w1q17<5 & w2q20!=. /*checking for observations with age<5 and included in the w2q20 variable. Result is no observations*/

/*NOTE:There is no variable to capture enrollment over past 12 months.
*Instead there is variable "w2q20" which captures whether an individual is registered
to attend formal education this year. So w2q20 is used to generate ATSCHOOL variable*/

recode w2q20 (2=0)
gen ATSCHOOL=w2q20 
lab val ATSCHOOL ATSCHOOL
lab def ATSCHOOL 1 "Yes" 0 "No",replace
lab var ATSCHOOL "Currently enrolled in school"

*CHECK*
tab ATSCHOOL,m /*no=59,701 observations, yes=24,419 observations, 15,109 missing observations*/

tab ATSCHOOL EVERATTD, m

replace ATSCHOOL=0 if ATSCHOOL==. & EVERATTD!=. /*76 changes made*/
/*7 individuals responded that they were in school but had never attended school
For these observations EVERATTD is recoded to 1 (YES)*/
replace EVERATTD=1 if EVERATTD==0 & ATSCHOOL==1
tab	ATSCHOOL, miss
*CHECK: Consistently coded: 15,033 missing values

*Generating EDLEVEL_AR variable*
*--------------------------------
*highest education level completed for those who are currently in school*
gen EDLEVEL_AR=.
replace EDLEVEL_AR=0 if (ATSCHOOL==1 & w2q19==0) 
replace EDLEVEL_AR=1 if (ATSCHOOL==1 & (w2q19>=1 & w2q19<=8)) 
replace EDLEVEL_AR=2 if (ATSCHOOL==1 & (w2q19>=9 & w2q19<=10)) 
replace EDLEVEL_AR=2 if (ATSCHOOL==1 & (w2q19==21|w2q19==22|w2q19==26|w2q19==28|w2q19==29)) 
replace EDLEVEL_AR=3 if (ATSCHOOL==1 & (w2q19==11|w2q19==12)|(w2q19==23|w2q19==24)) 
replace EDLEVEL_AR=4 if (ATSCHOOL==1 & (w2q19>=13 & w2q19<=19)) 
replace EDLEVEL_AR=4 if (ATSCHOOL==1 & (w2q19==25|w2q19==27)) 
replace EDLEVEL_AR=4 if (ATSCHOOL==1 & (w2q19>=30 & w2q19<=34)) 
replace EDLEVEL_AR=6 if (ATSCHOOL==1 & w2q19==20) 
replace EDLEVEL_AR=9 if (ATSCHOOL==1 & w2q19==98) 

*highest education level completed for those who are not currently in school*
replace EDLEVEL_AR=1 if (ATSCHOOL==0 & w2q19==0) 
replace EDLEVEL_AR=1 if (ATSCHOOL==0 & (w2q19>=1 & w2q19<=5)) 
replace EDLEVEL_AR=2 if (ATSCHOOL==0 & (w2q19>=6 & w2q19<=9)|(w2q19==21)) 
replace EDLEVEL_AR=3 if (ATSCHOOL==0 & (w2q19==10|w2q19==11|w2q19==22|w2q19==23|w2q19==26|w2q19==28|w2q19==29)) 
replace EDLEVEL_AR=4 if (ATSCHOOL==0 & (w2q19==12|w2q19==15|w2q19==16|w2q19==18|w2q19==24|w2q19==31|w2q19==32|w2q19==33)) 
replace EDLEVEL_AR=5 if (ATSCHOOL==0 & (w2q19==13|w2q19==14|w2q19==17|w2q19==25|w2q19==27|w2q19==30)) 
replace EDLEVEL_AR=6 if (ATSCHOOL==0 & (w2q19==19|w2q19==20|w2q19==34)) 
replace EDLEVEL_AR=9 if (ATSCHOOL==0 & w2q19==98) 


lab val EDLEVEL_AR EDLEVEL_AR
lab def EDLEVEL_AR 0 "No Education" ///
	1 "Pre-school/Primary not completed" ///
	2 "Completed primary,but less than completed lower secondary" ///
	3 "Completed lower secondary(or post-primary vocational education)but less than completed upper secondary" ///
	4 "Completed upper secondary (or extended vocational/technical education)" ///
	5 "Post secondary technical" ///
	6 "University and higher" ///
	7 "Formal adult education or literacy" ///
	9 "Other"
	
lab var EDLEVEL_AR "Highest level of education completed"

*Generating EDYEARS_AT variable*
*----------------------------------
*Years of education for those who are currently attending school*

gen EDYEARS_AT=. 
replace EDYEARS_AT=0 if (w2q19==0 & ATSCHOOL==1) 
replace EDYEARS_AT=1 if (w2q19==1 & ATSCHOOL==1) 
replace EDYEARS_AT=2 if (w2q19==2 & ATSCHOOL==1) 
replace EDYEARS_AT=3 if (w2q19==3 & ATSCHOOL==1) 
replace EDYEARS_AT=4 if (w2q19==4 & ATSCHOOL==1) 
replace EDYEARS_AT=5 if (w2q19==5 & ATSCHOOL==1) 
replace EDYEARS_AT=6 if (w2q19==6 & ATSCHOOL==1) 
replace EDYEARS_AT=7 if (w2q19==7 & ATSCHOOL==1) 
replace EDYEARS_AT=8 if (w2q19==8 & ATSCHOOL==1) 
replace EDYEARS_AT=9 if (w2q19==9 & ATSCHOOL==1) 
replace EDYEARS_AT=10 if (w2q19==10 & ATSCHOOL==1) 
replace EDYEARS_AT=11 if (w2q19==11 & ATSCHOOL==1) 
replace EDYEARS_AT=12 if (w2q19==12 & ATSCHOOL==1) 
*Grade 9-12 in new structure*
replace EDYEARS_AT=9 if (w2q19==21 & ATSCHOOL==1) 
replace EDYEARS_AT=10 if (w2q19==22 & ATSCHOOL==1) 
replace EDYEARS_AT=11 if (w2q19==23 & ATSCHOOL==1) 
replace EDYEARS_AT=12 if (w2q19==24 & ATSCHOOL==1) 

/*EDYEARS for those in programs resulting in certificates/diploma*/
*1)"certificate"=1 year after completing 12th grade*
replace EDYEARS_AT=13 if (w2q19==13 & ATSCHOOL==1) 
*2)certificate from TTC (2 years after 12th grade)*
replace EDYEARS_AT=14 if (w2q19==14 & ATSCHOOL==1) 
*3)Diploma (2 years after 12th grade)*
replace EDYEARS_AT=14 if (w2q19==17 & ATSCHOOL==1) 
*4)Diploma in new program (2 years after 12th grade)*
replace EDYEARS_AT=14 if (w2q19==30 & ATSCHOOL==1) 
*5)Certificate in 10+1 (1 year after 10th grade)*
replace EDYEARS_AT=11 if (w2q19==25 & ATSCHOOL==1) 
*6)10+1 & 10+2 program (2 years after 10th grade)*
replace EDYEARS_AT=12 if (w2q19==26 & ATSCHOOL==1) 
*7)certificate in 10+2 program (2 years after 10th grade)*
replace EDYEARS_AT=12 if (w2q19==27 & ATSCHOOL==1) 
*8)10+1 in 10+3 program (2 years after 10th grade)*
replace EDYEARS_AT=12 if (w2q19==28 & ATSCHOOL==1) 
*9)10+2 in 10+3 program (2 years after 10th grade)*
replace EDYEARS_AT=12 if (w2q19==29 & ATSCHOOL==1) 

/*EDYEARS for those in college/university*/
replace EDYEARS_AT=13 if (w2q19==15 & ATSCHOOL==1) 
replace EDYEARS_AT=14 if (w2q19==16 & ATSCHOOL==1) 
replace EDYEARS_AT=15 if (w2q19==18 & ATSCHOOL==1) 
replace EDYEARS_AT=16 if (w2q19==19 & ATSCHOOL==1) 
*College in new program*
replace EDYEARS_AT=13 if (w2q19==31 & ATSCHOOL==1) 
replace EDYEARS_AT=14 if (w2q19==32 & ATSCHOOL==1) 
replace EDYEARS_AT=15 if (w2q19==33 & ATSCHOOL==1) 
replace EDYEARS_AT=16 if (w2q19==34 & ATSCHOOL==1) 

*EDYEARS for those in above first degree (2 years after first degree)*
replace EDYEARS_AT=18 if (w2q19==20 & ATSCHOOL==1) 

lab val EDYEARS_AT EDYEARS_AT
lab var EDYEARS_AT "Years of education for currently enrolled"

*Generating EDYEARS variable*
*------------------------------
*Years of education for those who are not currently attending school*
*EDYEARS for kindergarten to Grade 12 education levels*
gen EDYEARS=. 
replace EDYEARS=0 if (w2q19==0 & ATSCHOOL==0) 
replace EDYEARS=1 if (w2q19==1 & ATSCHOOL==0) 
replace EDYEARS=2 if (w2q19==2 & ATSCHOOL==0) 
replace EDYEARS=3 if (w2q19==3 & ATSCHOOL==0) 
replace EDYEARS=4 if (w2q19==4 & ATSCHOOL==0) 
replace EDYEARS=5 if (w2q19==5 & ATSCHOOL==0) 
replace EDYEARS=6 if (w2q19==6 & ATSCHOOL==0) 
replace EDYEARS=7 if (w2q19==7 & ATSCHOOL==0) 
replace EDYEARS=8 if (w2q19==8 & ATSCHOOL==0) 
replace EDYEARS=9 if (w2q19==9 & ATSCHOOL==0) 
replace EDYEARS=10 if (w2q19==10 & ATSCHOOL==0) 
replace EDYEARS=11 if (w2q19==11 & ATSCHOOL==0) 
replace EDYEARS=12 if (w2q19==12 & ATSCHOOL==0) 
*Grade 9-12 in new structure*
replace EDYEARS=9 if (w2q19==21 & ATSCHOOL==0) 
replace EDYEARS=10 if (w2q19==22 & ATSCHOOL==0) 
replace EDYEARS=11 if (w2q19==23 & ATSCHOOL==0) 
replace EDYEARS=12 if (w2q19==24 & ATSCHOOL==0) 

*EDYEARS for those in programs resulting in certificates/diploma*
*1)"certificate"=1 year after completing 12th grade*
replace EDYEARS=13 if (w2q19==13 & ATSCHOOL==0) 
*2)certificate from TTC (2 years after 12th grade)*
replace EDYEARS=14 if (w2q19==14 & ATSCHOOL==0) 
*3)Diploma (2 years after 12th grade)*
replace EDYEARS=14 if (w2q19==17 & ATSCHOOL==0) 
*4)Diploma in new program (2 years after 12th grade)*
replace EDYEARS=14 if (w2q19==30 & ATSCHOOL==0) 
*5)Certificate in 10+1 (1 year after 10th grade)*
replace EDYEARS=11 if (w2q19==25 & ATSCHOOL==0) 
*6)10+1 & 10+2 program (2 years after 10th grade)*
replace EDYEARS=12 if (w2q19==26 & ATSCHOOL==0) 
*7)certificate in 10+2 program (2 years after 10th grade)*
replace EDYEARS=12 if (w2q19==27 & ATSCHOOL==0) 
*8)10+1 in 10+3 program (2 years after 10th grade)*
replace EDYEARS=12 if (w2q19==28 & ATSCHOOL==0) 
*9)10+2 in 10+3 program (2 years after 10th grade)*
replace EDYEARS=12 if (w2q19==29 & ATSCHOOL==0) 

/*EDYEARS for those in college/university*/
replace EDYEARS=13 if (w2q19==15 & ATSCHOOL==0) 
replace EDYEARS=14 if (w2q19==16 & ATSCHOOL==0) 
replace EDYEARS=15 if (w2q19==18 & ATSCHOOL==0) 
replace EDYEARS=16 if (w2q19==19 & ATSCHOOL==0) 
*College in new program*
replace EDYEARS=13 if (w2q19==31 & ATSCHOOL==0) 
replace EDYEARS=14 if (w2q19==32 & ATSCHOOL==0) 
replace EDYEARS=15 if (w2q19==33 & ATSCHOOL==0) 
replace EDYEARS=16 if (w2q19==34 & ATSCHOOL==0) 

*EDYEARS for those in above first degree (2 years after first degree)*
replace EDYEARS=18 if (w2q19==20 & ATSCHOOL==0) 

*for those who are currently in school*
*subtract one level for those currently attending*

replace EDYEARS=0 if (w2q19==0 & ATSCHOOL==1) 
replace EDYEARS=0 if (w2q19==1 & ATSCHOOL==1) 
replace EDYEARS=1 if (w2q19==2 & ATSCHOOL==1) 
replace EDYEARS=2 if (w2q19==3 & ATSCHOOL==1) 
replace EDYEARS=3 if (w2q19==4 & ATSCHOOL==1) 
replace EDYEARS=4 if (w2q19==5 & ATSCHOOL==1) 
replace EDYEARS=5 if (w2q19==6 & ATSCHOOL==1) 
replace EDYEARS=6 if (w2q19==7 & ATSCHOOL==1) 
replace EDYEARS=7 if (w2q19==8 & ATSCHOOL==1) 
replace EDYEARS=8 if (w2q19==9 & ATSCHOOL==1) 
replace EDYEARS=9 if (w2q19==10 & ATSCHOOL==1) 
replace EDYEARS=10 if (w2q19==11 & ATSCHOOL==1) 
replace EDYEARS=11 if (w2q19==12 & ATSCHOOL==1) 
*Grade 9-12 in new structure*
replace EDYEARS=8 if (w2q19==21 & ATSCHOOL==1) 
replace EDYEARS=9 if (w2q19==22 & ATSCHOOL==1) 
replace EDYEARS=10 if (w2q19==23 & ATSCHOOL==1) 
replace EDYEARS=11 if (w2q19==24 & ATSCHOOL==1) 

*EDYEARS for those in programs resulting in certificates/diploma*
*1)"certificate"=1 year after completing 12th grade*
replace EDYEARS=12 if (w2q19==13 & ATSCHOOL==1) 
*2)certificate from TTC (2 years after 12th grade)*
replace EDYEARS=13 if (w2q19==14 & ATSCHOOL==1) 
*3)Diploma (2 years after 12th grade)*
replace EDYEARS=13 if (w2q19==17 & ATSCHOOL==1) 
*4)Diploma in new program (2 years after 12th grade)*
replace EDYEARS=13 if (w2q19==30 & ATSCHOOL==1) 
*5)Certificate in 10+1 (1 year after 10th grade)*
replace EDYEARS=10 if (w2q19==25 & ATSCHOOL==1) 
*6)10+1 & 10+2 program (2 years after 10th grade)*
replace EDYEARS=11 if (w2q19==26 & ATSCHOOL==1) 
*7)certificate in 10+2 program (2 years after 10th grade)*
replace EDYEARS=11 if (w2q19==27 & ATSCHOOL==1) 
*8)10+1 in 10+3 program (2 years after 10th grade)*
replace EDYEARS=11 if (w2q19==28 & ATSCHOOL==1) 
*9)10+2 in 10+3 program (2 years after 10th grade)*
replace EDYEARS=11 if (w2q19==29 & ATSCHOOL==1) 

*EDYEARS for those in college/university*
replace EDYEARS=12 if (w2q19==15 & ATSCHOOL==1) 
replace EDYEARS=13 if (w2q19==16 & ATSCHOOL==1) 
replace EDYEARS=14 if (w2q19==18 & ATSCHOOL==1) 
replace EDYEARS=15 if (w2q19==19 & ATSCHOOL==1) 
*College in new program*
replace EDYEARS=12 if (w2q19==31 & ATSCHOOL==1) 
replace EDYEARS=13 if (w2q19==32 & ATSCHOOL==1) 
replace EDYEARS=14 if (w2q19==33 & ATSCHOOL==1) 
replace EDYEARS=15 if (w2q19==34 & ATSCHOOL==1) 

*EDYEARS for those in above first degree (2 years after first degree)*
replace EDYEARS=17 if (w2q19==20 & ATSCHOOL==1) 

lab val EDYEARS EDYEARS
lab var EDYEARS "Years of completed education"

*Generating SCHLTYP*
*--------------------
gen SCHLTYP=.
replace SCHLTYP=1 if w2q22==1
replace SCHLTYP=2 if [w2q22==2|w2q22==3|w2q22==4]
replace SCHLTYP=9 if [w2q22==5|w2q22==6]
lab val SCHLTYP SCHLTYP
lab def SCHLTYP 1 "Public" 2 "Private" 9 "Other",replace
lab var SCHLTYP "Type of school attending"

keep HID INDID LITERACY EVERATTD ATSCHOOL EDLEVEL_AR EDYEARS_AT EDYEARS SCHLTYP

sort HID INDID
merge HID INDID using "04_AGGDATA\ETH_2004_I.dta"
tab _merge /*_merge=1 (551 observations), _merge=2 (1,515 observations), _merge=3 (97,714 observations)*/
drop if _merge==1 
drop _merge

des  /*99,229 observations (individuals)*/

sort HID INDID

save "04_AGGDATA\ETH_2004_I.dta", replace
*-------------------------------------------------------------------------------------------
                                      
*Section 1.4: Health*
*---------------------

use "02_CLEANDATA\WMS\Member Characterstics and Child Nutrition.dta", clear

des /*98,265 observations (individuals)*/

sort HID
codebook HID /*21,595 households*/

*Renaming variable w1q13 to INDID*
*-----------------------------------
rename w1q13 INDID
lab val INDID INDID
label var INDID "Individual identification"

*Generating variable MORB_TR*
*-----------------------------
gen MORB_TR= 8
label var MORB_TR "Time reference for variable MORBID (weeks)"

*Generating MORBID variable*
*------------------------------
gen MORBID=w3q15
recode MORBID 2=0
lab val MORBID MORBID
lab def MORBID 1 "Yes" 0 "No",replace
lab var MORBID "Morbidity last MORB_TR"

*Generating RTREATM variable*
*-------------------------------
tab MORBID w3q18 /*cross-tabulation shows 2,839 individuals who did not face any health problem in last 8 weeks sought medical attention*/

gen RTREATM=.
replace RTREATM=1 if MORBID==1 & w3q18==1
replace RTREATM=0 if MORBID==1 & w3q18==2
lab val RTREATM RTREATM
lab def RTREATM 1 "Yes" 0 "No",replace
lab var RTREATM "Sought medical attention"

tab RTREATM MORBID /*tabulation shows that only individuals with morbid=1 are included in rtreatm*/

*Generating HLTHFAC variable*
*-----------------------------
gen HLTHFAC=.
replace HLTHFAC=1 if w3q19==1
replace HLTHFAC=2 if w3q19==3
replace HLTHFAC=3 if [w3q19==2|w3q19==4]
replace HLTHFAC=4 if w3q19==6 
replace HLTHFAC=5 if w3q19==8
replace HLTHFAC=6 if w3q19==0
replace HLTHFAC=9 if [w3q19==5|w3q19==7]
lab val HLTHFAC HLTHFAC
lab def HLTHFAC 1 "Hospital" 2 "Clinics" 3 "Dispensary, health center, health post" 4 "Outreach" 5 "Pharmacy" 6 "Traditional healer" 9 "Other"
lab var HLTHFAC "Health provider visited"

*Generating OWHPROVD variable*
*------------------------------
gen OWHPROVD=.
replace OWHPROVD=1 if [w3q19==1|w3q19==2|w3q19==3|w3q19==4]
replace OWHPROVD=2 if [w3q19==5|w3q19==7]
replace OWHPROVD=3 if w3q19==0
replace OWHPROVD=4 if w3q19==6
replace OWHPROVD=9 if w3q19==8
lab val OWHPROVD OWHPROVD
lab def OWHPROVD 1 "Public" 2 "Private-modern medicine" 3 "Private-traditional healers" 4 "Missionary/NGO" 9 "Other"
lab var OWHPROVD "Ownership of health provider visited"

keep HID INDID MORB_TR MORBID RTREATM HLTHFAC OWHPROVD

sort HID INDID
merge HID INDID using "04_AGGDATA\ETH_2004_I.dta"
tab _merge /*_merge=1(551 observations), _merge==2 (1515 observations),_merge=3 (97,714 observations)*/
drop if _merge==1
drop _merge

des  /*99,229 observations*/

sort HID INDID

save "04_AGGDATA\ETH_2004_I.dta", replace
*-----------------------------------------------------------------------------------------------

*Section 1.5:Child Survival and Anthropometry for Children Aged 0-59 Months*
*----------------------------------------------------------------------------

use "02_CLEANDATA\WMS\Member Characterstics and Child Nutrition.dta", clear

des /*98,265 observations (individuals)*/

codebook HID /*21,595 households*/

*Renaming variable w1q13 to INDID*
*-----------------------------------
rename w1q13 INDID
lab val INDID INDID
label var INDID "Individual identification"

*Generating AGEM variable*
*--------------------------
gen AGEM=w4q16
lab val AGEM AGEM 
lab var AGEM "Age of child in completed months"

*Generating WHDELIV variable*
*-----------------------------
gen WHDELIV=.
replace WHDELIV=1 if [w4q18==1|w4q18==2]
replace WHDELIV=2 if [w4q18==3|w4q18==4]
replace WHDELIV=9 if [w4q18==5|w4q18==6]
lab val WHDELIV WHDELIV
lab def WHDELIV 1 "Trained birth attendant" 2 "Traditional birth attendant" 3 "Relative/friend" 9 "Other",replace
lab var WHDELIV "Who helped assist child birth"

*Generating VCARD variable*
*----------------------------
*Assumption: Assume respondents who responded "No card" that their children have never been vaccinated*/

gen VCARD=.
replace VCARD=1 if [w4q19==1|w4q19==3]
replace VCARD=2 if w4q19==2
replace VCARD=3 if w4q19==4
lab val VCARD VCARD
lab def VCARD 1 "Yes" 2 "No, but child has been vaccinated" 3 "No,child never vaccinated"
lab var VCARD "Child has vaccine card"

*Generating BCG variable*
*-------------------------
gen BCG=.
replace BCG=1 if w4q21==1
replace BCG=0 if w4q21==2
lab val BCG BCG
lab def BCG 1 "Yes" 0 "No"
lab var BCG "Child immunized against BCG"

*Generating POLIO_DO variable*
*------------------------------
*It is necessary to recode w4q23a w4q23b w4q23c w4q23d so that the rowtotal of these variables inorder to avoid many possible permutations*

recode w4q23a 2=0
recode w4q23b 2=0
recode w4q23c 2=0
recode w4q23d 2=0

egen POLIO_DO= rowtotal (w4q23a w4q23b w4q23c w4q23d)

browse HID INDID w4q16 w4q23a w4q23b w4q23c w4q23d POLIO_DO if POLIO_DO==0

replace POLIO_DO=. if w4q23a==. & w4q23b==. & w4q23c==. & w4q23d==.

browse HID INDID w4q16 w4q23a w4q23b w4q23c w4q23d POLIO_DO if w4q23a==. & w4q23b==. & w4q23c==. & w4q23d==. 

label val POLIO_DO POLIO_DO
label def POLIO_DO 0 "No dose" 1 "One dose" 2 "Two doses" 3 "Three doses" 4 "More than three doses" 9 "Unspecified number of doses"
label var POLIO_DO "Number of doses of polio received"

*Generating DPT_DOSE variable*
*------------------------------
recode w4q22a 2=0
recode w4q22b 2=0
recode w4q22c 2=0

egen DPT_DOSE= rowtotal (w4q22a w4q22b w4q22c)

browse HID INDID w4q16 w4q22a w4q22b w4q22c DPT_DOSE if DPT_DOSE==0

replace DPT_DOSE=. if w4q22a==. & w4q22b==. & w4q22c==.

browse HID INDID w4q16 w4q22a w4q22b w4q22c DPT_DOSE if w4q22a==. & w4q22b==. & w4q22c==.

label val DPT_DOSE DPT_DOSE
label def DPT_DOSE 0 "No dose" 1 "One dose" 2 "Two doses" 3 "Three doses" 4 "More than three doses" 9 "Unspecified number of doses",replace
label var DPT_DOSE "Number of doses of DPT received"

*Generating MEASLES variable*
*-----------------------------
recode w4q20 2=0

gen MEASLES=w4q20
lab val MEASLES MEASLES 
lab def MEASLES 1 "Yes" 0 "No"
lab var MEASLES "Child immunized against measles"

*Generating VACCINE variable*
*-----------------------------
gen VACCINE=.
replace VACCINE=1 if [BCG==1 & [POLIO_DO==3|POLIO_DO==4] & [DPT_DOSE==3|DPT_DOSE==4] & MEASLES==1]
replace VACCINE=4 if BCG==0 & POLIO_DO==0 & DPT_DOSE==0 & MEASLES==0
replace VACCINE=2 if [BCG!=.|POLIO_DO!=.|DPT_DOSE!=.|MEASLES!=.] & VACCINE==.
replace VACCINE=. if BCG==. & POLIO_DO==. & DPT_DOSE==. & MEASLES==.
lab val VACCINE VACCINE
lab def VACCINE 1 "Fully immunized" 2 "Partially immunized" 3 "Immunized but no information on completeness" 4 "Not immunized",replace
lab var VACCINE "Immunization status of child"

browse BCG POLIO_DO  DPT_DOSE MEASLES VACCINE

*Generating WEIGHT variable*
*----------------------------
gen weightkg=weight/1000 if AGEM<=59
rename weightkg WEIGHT
label var WEIGHT "Weight of child(kg)"

*Generating HEIGHT variable*
*----------------------------
gen HEIGHT=.
label var HEIGHT "Height of child(cms)"

keep HID INDID AGEM WHDELIV VCARD BCG POLIO_DO DPT_DOSE MEASLES VACCINE WEIGHT HEIGHT 

sort HID INDID
merge HID INDID using "04_AGGDATA\ETH_2004_I.dta"
tab _merge /*_merge=1(551 observations), _merge==2 (1515 observations),_merge=3 (97,714 observations)*/
br if _merge==1 /*_merge=1 (551 observations), _merge=2 (1,515 observations), _merge=3 (97,714 observations)*/
drop if _merge==1
drop _merge

order COUNTRY REGION PROVINCE DISTRICT HID SURVEYR RURURB HHSIZE HHSIZE_S WTA_HH WTA_POP INDID ///
	SEX RELAT HEAD MARSTAT SP_PRES AGEY ETHNICITY LANGUAGE RELIGION LITERACY EVERATTD ///
	ATSCHOOL EDLEVEL_AR EDYEARS EDYEARS_AT SCHLTYP MORB_TR MORBID RTREATM HLTHFAC OWHPROVD ///
	AGEM WHDELIV VCARD BCG POLIO_DO DPT_DOSE MEASLES VACCINE WEIGHT HEIGHT ///

des  /*99,229 observations*/

sort HID INDID

save "04_AGGDATA\ETH_2004_I.dta", replace














